var SHA1 = (function(){
//
// A JavaScript implementation of the Secure Hash Algorithm, SHA-1, as defined
// in FIPS PUB 180-1
// Version 2.1a Copyright Paul Johnston 2000 - 2002.
// Other contributors: Greg Holt, Andrew Kepert, Ydnar, Lostinet
// Distributed under the BSD License
// See http://pajhome.org.uk/crypt/md5 for details.
//

//
// Configurable variables. You may need to tweak these to be compatible with
// the server-side, but the defaults work in most cases.
//

// hex output format. 0 - lowercase; 1 - uppercase
var hexcase = 0, b64pad  = "", chrsz   = 8,

// These are the functions you'll usually want to call
// They take string arguments and return either hex or base-64 encoded strings
hex_sha1 = function(s){return binb2hex(core_sha1(str2binb(s),s.length * chrsz));},
b64_sha1 = function(s){return binb2b64(core_sha1(str2binb(s),s.length * chrsz));},
str_sha1 = function(s){return binb2str(core_sha1(str2binb(s),s.length * chrsz));},
hex_hmac_sha1 = function(key, data){ return binb2hex(core_hmac_sha1(key, data));},
b64_hmac_sha1 = function(key, data){ return binb2b64(core_hmac_sha1(key, data));},
str_hmac_sha1 = function(key, data){ return binb2str(core_hmac_sha1(key, data));},

//Perform a simple self-test to see if the VM is working
sha1_vm_test = function(){ return hex_sha1("abc") == "a9993e364706816aba3e25717850c26c9cd0d89d";},

// Calculate the SHA-1 of an array of big-endian words, and a bit length
core_sha1 = function(x, len) 
{
  // append padding
  x[len >> 5] |= 0x80 << (24 - len % 32);
  x[((len + 64 >> 9) << 4) + 15] = len;

  var w = Array(80);
  var a =  1732584193;
  var b = -271733879;
  var c = -1732584194;
  var d =  271733878;
  var e = -1009589776;

  for(var i = 0; i < x.length; i += 16)
  {
    var olda = a;
    var oldb = b;
    var oldc = c;
    var oldd = d;
    var olde = e;

    for(var j = 0; j < 80; j++)
    {
      if(j < 16) w[j] = x[i + j];
      else w[j] = rol(w[j-3] ^ w[j-8] ^ w[j-14] ^ w[j-16], 1);
      var t = safe_add(safe_add(rol(a, 5), sha1_ft(j, b, c, d)),
                       safe_add(safe_add(e, w[j]), sha1_kt(j)));
      e = d;
      d = c;
      c = rol(b, 30);
      b = a;
      a = t;
    }

    a = safe_add(a, olda);
    b = safe_add(b, oldb);
    c = safe_add(c, oldc);
    d = safe_add(d, oldd);
    e = safe_add(e, olde);
  }
  return Array(a, b, c, d, e);

},

// Perform the appropriate triplet combination function for the current
// iteration
sha1_ft = function(t, b, c, d)
{
  if(t < 20) return (b & c) | ((~b) & d);
  if(t < 40) return b ^ c ^ d;
  if(t < 60) return (b & c) | (b & d) | (c & d);
  return b ^ c ^ d;
},

// Determine the appropriate additive constant for the current iteration
sha1_kt = function(t)
{
  return (t < 20) ?  1518500249 : (t < 40) ?  1859775393 :
         (t < 60) ? -1894007588 : -899497514;
},

// Calculate the HMAC-SHA1 of a key and some data
core_hmac_sha1 = function(key, data)
{
  var bkey = str2binb(key);
  if(bkey.length > 16) bkey = core_sha1(bkey, key.length * chrsz);

  var ipad = Array(16), opad = Array(16);
  for(var i = 0; i < 16; i++)
  {
    ipad[i] = bkey[i] ^ 0x36363636;
    opad[i] = bkey[i] ^ 0x5C5C5C5C;
  }

  var hash = core_sha1(ipad.concat(str2binb(data)), 512 + data.length * chrsz);
  return core_sha1(opad.concat(hash), 512 + 160);
},

// Add integers, wrapping at 2^32. This uses 16-bit operations internally
// to work around bugs in some JS interpreters.
safe_add = function(x, y)
{
  var lsw = (x & 0xFFFF) + (y & 0xFFFF);
  var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
  return (msw << 16) | (lsw & 0xFFFF);
},

// Bitwise rotate a 32-bit number to the left.
rol = function(num, cnt)
{
  return (num << cnt) | (num >>> (32 - cnt));
},

// Convert an 8-bit or 16-bit string to an array of big-endian words
// In 8-bit function, characters >255 have their hi-byte silently ignored.
str2binb = function(str)
{
  var bin = Array();
  var mask = (1 << chrsz) - 1;
  for(var i = 0; i < str.length * chrsz; i += chrsz)
    bin[i>>5] |= (str.charCodeAt(i / chrsz) & mask) << (32 - chrsz - i%32);
  return bin;
},

// Convert an array of big-endian words to a string
binb2str = function (bin)
{
  var str = "";
  var mask = (1 << chrsz) - 1;
  for(var i = 0; i < bin.length * 32; i += chrsz)
    str += String.fromCharCode((bin[i>>5] >>> (32 - chrsz - i%32)) & mask);
  return str;
},

// Convert an array of big-endian words to a hex string.
binb2hex = function(binarray)
{
  var hex_tab = hexcase ? "0123456789ABCDEF" : "0123456789abcdef";
  var str = "";
  for(var i = 0; i < binarray.length * 4; i++)
  {
    str += hex_tab.charAt((binarray[i>>2] >> ((3 - i%4)*8+4)) & 0xF) +
           hex_tab.charAt((binarray[i>>2] >> ((3 - i%4)*8  )) & 0xF);
  }
  return str;
},

hex2bin = function(hex_str)
{
	var char_str = "";
	var num_str = "";
	var i;
	for(i=0; i < hex_str.length; i+=2) {
		char_str += String.fromCharCode(parseInt(hex_str.substring(i, i+2), 16));
	}
	return char_str;
},

// Convert an array of big-endian words to a base-64 string
binb2b64 = function(binarray)
{
  var tab = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
  var str = "";
  for(var i = 0; i < binarray.length * 4; i += 3)
  {
    var triplet = (((binarray[i   >> 2] >> 8 * (3 -  i   %4)) & 0xFF) << 16)
                | (((binarray[i+1 >> 2] >> 8 * (3 - (i+1)%4)) & 0xFF) << 8 )
                |  ((binarray[i+2 >> 2] >> 8 * (3 - (i+2)%4)) & 0xFF);
    for(var j = 0; j < 4; j++)
    {
      if(i * 8 + j * 6 > binarray.length * 32) str += b64pad;
      else str += tab.charAt((triplet >> 6*(3-j)) & 0x3F);
    }
  }
  return str;
};

    return {
        "hex2bin":hex2bin,
        "binb2hex":binb2hex,
		"core_sha1":core_sha1,
		"str2binb":str2binb
    };
})();

var SHA256 = (function(){
/*
* A JavaScript implementation of the SHA256 hash function.
*
* FILE:	sha256.js
* VERSION:	0.8
* AUTHOR:	Christoph Bichlmeier <informatik@zombiearena.de>
*
* NOTE: This version is not tested thoroughly!
*
* Copyright (c) 2003, Christoph Bichlmeier
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
* 3. Neither the name of the copyright holder nor the names of contributors
*    may be used to endorse or promote products derived from this software
*    without specific prior written permission.
*
* ======================================================================
*
* THIS SOFTWARE IS PROVIDED BY THE AUTHORS ''AS IS'' AND ANY EXPRESS
* OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
* BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
* WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
* EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

var ihash, count, buffer,
sha256_hex_digits = "0123456789abcdef",

/* SHA256 logical functions */
rotateRight = function(n,x) {
	return ((x >>> n) | (x << (32 - n)));
},
choice = function(x,y,z) {
	return ((x & y) ^ (~x & z));
},
majority = function(x,y,z) {
	return ((x & y) ^ (x & z) ^ (y & z));
},
sha256_Sigma0 = function(x) {
	return (rotateRight(2, x) ^ rotateRight(13, x) ^ rotateRight(22, x));
},
sha256_Sigma1 = function(x) {
	return (rotateRight(6, x) ^ rotateRight(11, x) ^ rotateRight(25, x));
},
sha256_sigma0 = function(x) {
	return (rotateRight(7, x) ^ rotateRight(18, x) ^ (x >>> 3));
},
sha256_sigma1 = function(x) {
	return (rotateRight(17, x) ^ rotateRight(19, x) ^ (x >>> 10));
},
sha256_expand = function(W, j) {
	return (W[j&0x0f] += sha256_sigma1(W[(j+14)&0x0f]) + W[(j+9)&0x0f] + 
sha256_sigma0(W[(j+1)&0x0f]));
},

/* Hash constant words K: */
K256 = new Array(
	0x428a2f98, 0x71374491, 0xb5c0fbcf, 0xe9b5dba5,
	0x3956c25b, 0x59f111f1, 0x923f82a4, 0xab1c5ed5,
	0xd807aa98, 0x12835b01, 0x243185be, 0x550c7dc3,
	0x72be5d74, 0x80deb1fe, 0x9bdc06a7, 0xc19bf174,
	0xe49b69c1, 0xefbe4786, 0x0fc19dc6, 0x240ca1cc,
	0x2de92c6f, 0x4a7484aa, 0x5cb0a9dc, 0x76f988da,
	0x983e5152, 0xa831c66d, 0xb00327c8, 0xbf597fc7,
	0xc6e00bf3, 0xd5a79147, 0x06ca6351, 0x14292967,
	0x27b70a85, 0x2e1b2138, 0x4d2c6dfc, 0x53380d13,
	0x650a7354, 0x766a0abb, 0x81c2c92e, 0x92722c85,
	0xa2bfe8a1, 0xa81a664b, 0xc24b8b70, 0xc76c51a3,
	0xd192e819, 0xd6990624, 0xf40e3585, 0x106aa070,
	0x19a4c116, 0x1e376c08, 0x2748774c, 0x34b0bcb5,
	0x391c0cb3, 0x4ed8aa4a, 0x5b9cca4f, 0x682e6ff3,
	0x748f82ee, 0x78a5636f, 0x84c87814, 0x8cc70208,
	0x90befffa, 0xa4506ceb, 0xbef9a3f7, 0xc67178f2
),

/* Add 32-bit integers with 16-bit operations (bug in some JS-interpreters: 
overflow) */
safe_add = function(x, y)
{
	var lsw = (x & 0xffff) + (y & 0xffff);
	var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
	return (msw << 16) | (lsw & 0xffff);
},

/* Initialise the SHA256 computation */
sha256_init = function() {
	ihash = new Array(8);
	count = new Array(2);
	buffer = new Array(64);
	count[0] = count[1] = 0;
	ihash[0] = 0x6a09e667;
	ihash[1] = 0xbb67ae85;
	ihash[2] = 0x3c6ef372;
	ihash[3] = 0xa54ff53a;
	ihash[4] = 0x510e527f;
	ihash[5] = 0x9b05688c;
	ihash[6] = 0x1f83d9ab;
	ihash[7] = 0x5be0cd19;
},

/* Transform a 512-bit message block */
sha256_transform = function() {
	var a, b, c, d, e, f, g, h, T1, T2;
	var W = new Array(16);

	/* Initialize registers with the previous intermediate value */
	a = ihash[0];
	b = ihash[1];
	c = ihash[2];
	d = ihash[3];
	e = ihash[4];
	f = ihash[5];
	g = ihash[6];
	h = ihash[7];

        /* make 32-bit words */
	for(var i=0; i<16; i++)
		W[i] = ((buffer[(i<<2)+3]) | (buffer[(i<<2)+2] << 8) | (buffer[(i<<2)+1] << 16) | (buffer[i<<2] << 24));

        for(var j=0; j<64; j++) {
		T1 = h + sha256_Sigma1(e) + choice(e, f, g) + K256[j];
		if(j < 16) T1 += W[j];
		else T1 += sha256_expand(W, j);
		T2 = sha256_Sigma0(a) + majority(a, b, c);
		h = g;
		g = f;
		f = e;
		e = safe_add(d, T1);
		d = c;
		c = b;
		b = a;
		a = safe_add(T1, T2);
        }

	/* Compute the current intermediate hash value */
	ihash[0] += a;
	ihash[1] += b;
	ihash[2] += c;
	ihash[3] += d;
	ihash[4] += e;
	ihash[5] += f;
	ihash[6] += g;
	ihash[7] += h;
},

/* Read the next chunk of data and update the SHA256 computation */
sha256_update = function(data, inputLen) {
	var i, index, curpos = 0;
	/* Compute number of bytes mod 64 */
	index = ((count[0] >> 3) & 0x3f);
        var remainder = (inputLen & 0x3f);

	/* Update number of bits */
	if ((count[0] += (inputLen << 3)) < (inputLen << 3)) count[1]++;
	count[1] += (inputLen >> 29);

	/* Transform as many times as possible */
	for(i=0; i+63<inputLen; i+=64) {
                for(var j=index; j<64; j++)
			buffer[j] = data.charCodeAt(curpos++);
		sha256_transform();
		index = 0;
	}

	/* Buffer remaining input */
	for(var j=0; j<remainder; j++)
		buffer[j] = data.charCodeAt(curpos++);
},

/* Finish the computation by operations such as padding */
sha256_final = function() {
	var index = ((count[0] >> 3) & 0x3f);
        buffer[index++] = 0x80;
        if(index <= 56) {
		for(var i=index; i<56; i++)
			buffer[i] = 0;
        } else {
		for(var i=index; i<64; i++)
			buffer[i] = 0;
                sha256_transform();
                for(var i=0; i<56; i++)
			buffer[i] = 0;
	}
        buffer[56] = (count[1] >>> 24) & 0xff;
        buffer[57] = (count[1] >>> 16) & 0xff;
        buffer[58] = (count[1] >>> 8) & 0xff;
        buffer[59] = count[1] & 0xff;
        buffer[60] = (count[0] >>> 24) & 0xff;
        buffer[61] = (count[0] >>> 16) & 0xff;
        buffer[62] = (count[0] >>> 8) & 0xff;
        buffer[63] = count[0] & 0xff;
        sha256_transform();
},

/* Split the internal hash values into an array of bytes */
sha256_encode_bytes = function() {
        var j=0;
        var output = new Array(32);
	for(var i=0; i<8; i++) {
		output[j++] = ((ihash[i] >>> 24) & 0xff);
		output[j++] = ((ihash[i] >>> 16) & 0xff);
		output[j++] = ((ihash[i] >>> 8) & 0xff);
		output[j++] = (ihash[i] & 0xff);
	}
	return output;
},

/* Get the internal hash as a hex string */
sha256_encode_hex = function() {
	var output = new String();
	for(var i=0; i<8; i++) {
		for(var j=28; j>=0; j-=4)
			output += sha256_hex_digits.charAt((ihash[i] >>> j) & 0x0f);
	}
	return output;
},

/* Main function: returns a hex string representing the SHA256 value of the 
given data */
sha256_digest = function(data) {
	sha256_init();
	sha256_update(data, data.length);
	sha256_final();
        return sha256_encode_hex();
},

/* test if the JS-interpreter is working properly */
sha256_self_test = function()
{
	return sha256_digest("message digest") == 
"f7846f55cf23e14eebeab5b4e1550cad5b509e3348fbc4efa3a1413d393cb650";
};

return {
	"sha256_digest": sha256_digest,
	"sha256_self_test": sha256_self_test
};
})();
"use strict";var sjcl={cipher:{},hash:{},keyexchange:{},mode:{},misc:{},codec:{},exception:{corrupt:function(a){this.toString=function(){return"CORRUPT: "+this.message};this.message=a},invalid:function(a){this.toString=function(){return"INVALID: "+this.message};this.message=a},bug:function(a){this.toString=function(){return"BUG: "+this.message};this.message=a},notReady:function(a){this.toString=function(){return"NOT READY: "+this.message};this.message=a}}};
sjcl.cipher.aes=function(a){this.o[0][0][0]||this.r();var b,c,d,e,f=this.o[0][4],g=this.o[1];b=a.length;var h=1;if(b!==4&&b!==6&&b!==8)throw new sjcl.exception.invalid("invalid aes key size");this.d=[d=a.slice(0),e=[]];for(a=b;a<4*b+28;a++){c=d[a-1];if(a%b===0||b===8&&a%b===4){c=f[c>>>24]<<24^f[c>>16&255]<<16^f[c>>8&255]<<8^f[c&255];if(a%b===0){c=c<<8^c>>>24^h<<24;h=h<<1^(h>>7)*283}}d[a]=d[a-b]^c}for(b=0;a;b++,a--){c=d[b&3?a:a-4];e[b]=a<=4||b<4?c:g[0][f[c>>>24]]^g[1][f[c>>16&255]]^g[2][f[c>>8&255]]^
g[3][f[c&255]]}};
sjcl.cipher.aes.prototype={encrypt:function(a){return this.N(a,0)},decrypt:function(a){return this.N(a,1)},o:[[[],[],[],[],[]],[[],[],[],[],[]]],r:function(){var a=this.o[0],b=this.o[1],c=a[4],d=b[4],e,f,g,h=[],i=[],k,j,l,m;for(e=0;e<0x100;e++)i[(h[e]=e<<1^(e>>7)*283)^e]=e;for(f=g=0;!c[f];f^=k||1,g=i[g]||1){l=g^g<<1^g<<2^g<<3^g<<4;l=l>>8^l&255^99;c[f]=l;d[l]=f;j=h[e=h[k=h[f]]];m=j*0x1010101^e*0x10001^k*0x101^f*0x1010100;j=h[l]*0x101^l*0x1010100;for(e=0;e<4;e++){a[e][f]=j=j<<24^j>>>8;b[e][l]=m=m<<24^m>>>8}}for(e=
0;e<5;e++){a[e]=a[e].slice(0);b[e]=b[e].slice(0)}},N:function(a,b){if(a.length!==4)throw new sjcl.exception.invalid("invalid aes block size");var c=this.d[b],d=a[0]^c[0],e=a[b?3:1]^c[1],f=a[2]^c[2];a=a[b?1:3]^c[3];var g,h,i,k=c.length/4-2,j,l=4,m=[0,0,0,0];g=this.o[b];var n=g[0],o=g[1],p=g[2],q=g[3],r=g[4];for(j=0;j<k;j++){g=n[d>>>24]^o[e>>16&255]^p[f>>8&255]^q[a&255]^c[l];h=n[e>>>24]^o[f>>16&255]^p[a>>8&255]^q[d&255]^c[l+1];i=n[f>>>24]^o[a>>16&255]^p[d>>8&255]^q[e&255]^c[l+2];a=n[a>>>24]^o[d>>16&
255]^p[e>>8&255]^q[f&255]^c[l+3];l+=4;d=g;e=h;f=i}for(j=0;j<4;j++){m[b?3&-j:j]=r[d>>>24]<<24^r[e>>16&255]<<16^r[f>>8&255]<<8^r[a&255]^c[l++];g=d;d=e;e=f;f=a;a=g}return m}};
sjcl.bitArray={bitSlice:function(a,b,c){a=sjcl.bitArray.T(a.slice(b/32),32-(b&31)).slice(1);return c===undefined?a:sjcl.bitArray.clamp(a,c-b)},extract:function(a,b,c){var d=Math.floor(-b-c&31);return((b+c-1^b)&-32?a[b/32|0]<<32-d^a[b/32+1|0]>>>d:a[b/32|0]>>>d)&(1<<c)-1},concat:function(a,b){if(a.length===0||b.length===0)return a.concat(b);var c=a[a.length-1],d=sjcl.bitArray.getPartial(c);return d===32?a.concat(b):sjcl.bitArray.T(b,d,c|0,a.slice(0,a.length-1))},bitLength:function(a){var b=a.length;
if(b===0)return 0;return(b-1)*32+sjcl.bitArray.getPartial(a[b-1])},clamp:function(a,b){if(a.length*32<b)return a;a=a.slice(0,Math.ceil(b/32));var c=a.length;b&=31;if(c>0&&b)a[c-1]=sjcl.bitArray.partial(b,a[c-1]&2147483648>>b-1,1);return a},partial:function(a,b,c){if(a===32)return b;return(c?b|0:b<<32-a)+a*0x10000000000},getPartial:function(a){return Math.round(a/0x10000000000)||32},equal:function(a,b){if(sjcl.bitArray.bitLength(a)!==sjcl.bitArray.bitLength(b))return false;var c=0,d;for(d=0;d<a.length;d++)c|=
a[d]^b[d];return c===0},T:function(a,b,c,d){var e;e=0;if(d===undefined)d=[];for(;b>=32;b-=32){d.push(c);c=0}if(b===0)return d.concat(a);for(e=0;e<a.length;e++){d.push(c|a[e]>>>b);c=a[e]<<32-b}e=a.length?a[a.length-1]:0;a=sjcl.bitArray.getPartial(e);d.push(sjcl.bitArray.partial(b+a&31,b+a>32?c:d.pop(),1));return d},k:function(a,b){return[a[0]^b[0],a[1]^b[1],a[2]^b[2],a[3]^b[3]]}};
sjcl.codec.utf8String={fromBits:function(a){var b="",c=sjcl.bitArray.bitLength(a),d,e;for(d=0;d<c/8;d++){if((d&3)===0)e=a[d/4];b+=String.fromCharCode(e>>>24);e<<=8}return decodeURIComponent(escape(b))},toBits:function(a){a=unescape(encodeURIComponent(a));var b=[],c,d=0;for(c=0;c<a.length;c++){d=d<<8|a.charCodeAt(c);if((c&3)===3){b.push(d);d=0}}c&3&&b.push(sjcl.bitArray.partial(8*(c&3),d));return b}};
sjcl.codec.hex={fromBits:function(a){var b="",c;for(c=0;c<a.length;c++)b+=((a[c]|0)+0xf00000000000).toString(16).substr(4);return b.substr(0,sjcl.bitArray.bitLength(a)/4)},toBits:function(a){var b,c=[],d;a=a.replace(/\s|0x/g,"");d=a.length;a+="00000000";for(b=0;b<a.length;b+=8)c.push(parseInt(a.substr(b,8),16)^0);return sjcl.bitArray.clamp(c,d*4)}};
sjcl.codec.base64={K:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",fromBits:function(a,b){var c="",d,e=0,f=sjcl.codec.base64.K,g=0,h=sjcl.bitArray.bitLength(a);for(d=0;c.length*6<h;){c+=f.charAt((g^a[d]>>>e)>>>26);if(e<6){g=a[d]<<6-e;e+=26;d++}else{g<<=6;e-=6}}for(;c.length&3&&!b;)c+="=";return c},toBits:function(a){a=a.replace(/\s|=/g,"");var b=[],c,d=0,e=sjcl.codec.base64.K,f=0,g;for(c=0;c<a.length;c++){g=e.indexOf(a.charAt(c));if(g<0)throw new sjcl.exception.invalid("this isn't base64: '"+
a.charAt(c)+"', "+c+" -- "+a.length);if(d>26){d-=26;b.push(f^g>>>d);f=g<<32-d}else{d+=6;f^=g<<32-d}}d&56&&b.push(sjcl.bitArray.partial(d&56,f,1));return b}};sjcl.codec.bytes={fromBits:function(a){var b=[],c=sjcl.bitArray.bitLength(a),d,e;for(d=0;d<c/8;d++){if((d&3)===0)e=a[d/4];b.push(e>>>24);e<<=8}return b},toBits:function(a){var b=[],c,d=0;for(c=0;c<a.length;c++){d=d<<8|a[c];if((c&3)===3){b.push(d);d=0}}c&3&&b.push(sjcl.bitArray.partial(8*(c&3),d));return b}};
sjcl.hash.sha256=function(a){this.d[0]||this.r();if(a){this.c=a.c.slice(0);this.b=a.b.slice(0);this.a=a.a}else this.reset()};sjcl.hash.sha256.hash=function(a){return(new sjcl.hash.sha256).update(a).finalize()};
sjcl.hash.sha256.prototype={blockSize:512,reset:function(){this.c=this.l.slice(0);this.b=[];this.a=0;return this},update:function(a){if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);var b,c=this.b=sjcl.bitArray.concat(this.b,a);b=this.a;a=this.a=b+sjcl.bitArray.bitLength(a);for(b=512+b&-512;b<=a;b+=512)this.g(c.splice(0,16));return this},finalize:function(){var a,b=this.b,c=this.c;b=sjcl.bitArray.concat(b,[sjcl.bitArray.partial(1,1)]);for(a=b.length+2;a&15;a++)b.push(0);b.push(Math.floor(this.a/
4294967296));for(b.push(this.a|0);b.length;)this.g(b.splice(0,16));this.reset();return c},l:[],d:[],r:function(){function a(e){return(e-Math.floor(e))*0x100000000|0}var b=0,c=2,d;a:for(;b<64;c++){for(d=2;d*d<=c;d++)if(c%d===0)continue a;if(b<8)this.l[b]=a(Math.pow(c,0.5));this.d[b]=a(Math.pow(c,1/3));b++}},g:function(a){var b,c,d=a.slice(0),e=this.c,f=this.d,g=e[0],h=e[1],i=e[2],k=e[3],j=e[4],l=e[5],m=e[6],n=e[7];for(a=0;a<64;a++){if(a<16)b=d[a];else{b=d[a+1&15];c=d[a+14&15];b=d[a&15]=(b>>>7^b>>>18^
b>>>3^b<<25^b<<14)+(c>>>17^c>>>19^c>>>10^c<<15^c<<13)+d[a&15]+d[a+9&15]|0}b=b+n+(j>>>6^j>>>11^j>>>25^j<<26^j<<21^j<<7)+(m^j&(l^m))+f[a];n=m;m=l;l=j;j=k+b|0;k=i;i=h;h=g;g=b+(h&i^k&(h^i))+(h>>>2^h>>>13^h>>>22^h<<30^h<<19^h<<10)|0}e[0]=e[0]+g|0;e[1]=e[1]+h|0;e[2]=e[2]+i|0;e[3]=e[3]+k|0;e[4]=e[4]+j|0;e[5]=e[5]+l|0;e[6]=e[6]+m|0;e[7]=e[7]+n|0}};
sjcl.mode.ccm={name:"ccm",encrypt:function(a,b,c,d,e){var f,g=b.slice(0),h=sjcl.bitArray,i=h.bitLength(c)/8,k=h.bitLength(g)/8;e=e||64;d=d||[];if(i<7)throw new sjcl.exception.invalid("ccm: iv must be at least 7 bytes");for(f=2;f<4&&k>>>8*f;f++);if(f<15-i)f=15-i;c=h.clamp(c,8*(15-f));b=sjcl.mode.ccm.M(a,b,c,d,e,f);g=sjcl.mode.ccm.O(a,g,c,b,e,f);return h.concat(g.data,g.tag)},decrypt:function(a,b,c,d,e){e=e||64;d=d||[];var f=sjcl.bitArray,g=f.bitLength(c)/8,h=f.bitLength(b),i=f.clamp(b,h-e),k=f.bitSlice(b,
h-e);h=(h-e)/8;if(g<7)throw new sjcl.exception.invalid("ccm: iv must be at least 7 bytes");for(b=2;b<4&&h>>>8*b;b++);if(b<15-g)b=15-g;c=f.clamp(c,8*(15-b));i=sjcl.mode.ccm.O(a,i,c,k,e,b);a=sjcl.mode.ccm.M(a,i.data,c,d,e,b);if(!f.equal(i.tag,a))throw new sjcl.exception.corrupt("ccm: tag doesn't match");return i.data},M:function(a,b,c,d,e,f){var g=[],h=sjcl.bitArray,i=h.k;e/=8;if(e%2||e<4||e>16)throw new sjcl.exception.invalid("ccm: invalid tag length");if(d.length>0xffffffff||b.length>0xffffffff)throw new sjcl.exception.bug("ccm: can't deal with 4GiB or more data");
f=[h.partial(8,(d.length?64:0)|e-2<<2|f-1)];f=h.concat(f,c);f[3]|=h.bitLength(b)/8;f=a.encrypt(f);if(d.length){c=h.bitLength(d)/8;if(c<=65279)g=[h.partial(16,c)];else if(c<=0xffffffff)g=h.concat([h.partial(16,65534)],[c]);g=h.concat(g,d);for(d=0;d<g.length;d+=4)f=a.encrypt(i(f,g.slice(d,d+4).concat([0,0,0])))}for(d=0;d<b.length;d+=4)f=a.encrypt(i(f,b.slice(d,d+4).concat([0,0,0])));return h.clamp(f,e*8)},O:function(a,b,c,d,e,f){var g,h=sjcl.bitArray;g=h.k;var i=b.length,k=h.bitLength(b);c=h.concat([h.partial(8,
f-1)],c).concat([0,0,0]).slice(0,4);d=h.bitSlice(g(d,a.encrypt(c)),0,e);if(!i)return{tag:d,data:[]};for(g=0;g<i;g+=4){c[3]++;e=a.encrypt(c);b[g]^=e[0];b[g+1]^=e[1];b[g+2]^=e[2];b[g+3]^=e[3]}return{tag:d,data:h.clamp(b,k)}}};
sjcl.mode.ocb2={name:"ocb2",encrypt:function(a,b,c,d,e,f){if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("ocb iv must be 128 bits");var g,h=sjcl.mode.ocb2.H,i=sjcl.bitArray,k=i.k,j=[0,0,0,0];c=h(a.encrypt(c));var l,m=[];d=d||[];e=e||64;for(g=0;g+4<b.length;g+=4){l=b.slice(g,g+4);j=k(j,l);m=m.concat(k(c,a.encrypt(k(c,l))));c=h(c)}l=b.slice(g);b=i.bitLength(l);g=a.encrypt(k(c,[0,0,0,b]));l=i.clamp(k(l.concat([0,0,0]),g),b);j=k(j,k(l.concat([0,0,0]),g));j=a.encrypt(k(j,k(c,h(c))));
if(d.length)j=k(j,f?d:sjcl.mode.ocb2.pmac(a,d));return m.concat(i.concat(l,i.clamp(j,e)))},decrypt:function(a,b,c,d,e,f){if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("ocb iv must be 128 bits");e=e||64;var g=sjcl.mode.ocb2.H,h=sjcl.bitArray,i=h.k,k=[0,0,0,0],j=g(a.encrypt(c)),l,m,n=sjcl.bitArray.bitLength(b)-e,o=[];d=d||[];for(c=0;c+4<n/32;c+=4){l=i(j,a.decrypt(i(j,b.slice(c,c+4))));k=i(k,l);o=o.concat(l);j=g(j)}m=n-c*32;l=a.encrypt(i(j,[0,0,0,m]));l=i(l,h.clamp(b.slice(c),
m).concat([0,0,0]));k=i(k,l);k=a.encrypt(i(k,i(j,g(j))));if(d.length)k=i(k,f?d:sjcl.mode.ocb2.pmac(a,d));if(!h.equal(h.clamp(k,e),h.bitSlice(b,n)))throw new sjcl.exception.corrupt("ocb: tag doesn't match");return o.concat(h.clamp(l,m))},pmac:function(a,b){var c,d=sjcl.mode.ocb2.H,e=sjcl.bitArray,f=e.k,g=[0,0,0,0],h=a.encrypt([0,0,0,0]);h=f(h,d(d(h)));for(c=0;c+4<b.length;c+=4){h=d(h);g=f(g,a.encrypt(f(h,b.slice(c,c+4))))}b=b.slice(c);if(e.bitLength(b)<128){h=f(h,d(h));b=e.concat(b,[2147483648|0,0,
0,0])}g=f(g,b);return a.encrypt(f(d(f(h,d(h))),g))},H:function(a){return[a[0]<<1^a[1]>>>31,a[1]<<1^a[2]>>>31,a[2]<<1^a[3]>>>31,a[3]<<1^(a[0]>>>31)*135]}};sjcl.misc.hmac=function(a,b){this.p=b=b||sjcl.hash.sha256;var c=[[],[]],d=b.prototype.blockSize/32;this.e=[new b,new b];if(a.length>d)a=b.hash(a);for(b=0;b<d;b++){c[0][b]=a[b]^909522486;c[1][b]=a[b]^1549556828}this.e[0].update(c[0]);this.e[1].update(c[1])};
sjcl.misc.hmac.prototype.encrypt=sjcl.misc.hmac.prototype.mac=function(a,b){a=(new this.p(this.e[0])).update(a,b).finalize();return(new this.p(this.e[1])).update(a).finalize()};sjcl.hash.sha1=function(a){if(a){this.c=a.c.slice(0);this.b=a.b.slice(0);this.a=a.a}else this.reset()};sjcl.hash.sha1.hash=function(a){return(new sjcl.hash.sha1).update(a).finalize()};
sjcl.hash.sha1.prototype={blockSize:512,reset:function(){this.c=this.l.slice(0);this.b=[];this.a=0;return this},update:function(a){if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);var b,c=this.b=sjcl.bitArray.concat(this.b,a);b=this.a;a=this.a=b+sjcl.bitArray.bitLength(a);for(b=this.blockSize+b&-this.blockSize;b<=a;b+=this.blockSize)this.g(c.splice(0,16));return this},finalize:function(){var a,b=this.b,c=this.c;b=sjcl.bitArray.concat(b,[sjcl.bitArray.partial(1,1)]);for(a=b.length+2;a&15;a++)b.push(0);
b.push(Math.floor(this.a/0x100000000));for(b.push(this.a|0);b.length;)this.g(b.splice(0,16));this.reset();return c},l:[1732584193,4023233417,2562383102,271733878,3285377520],d:[1518500249,1859775393,2400959708,3395469782],X:function(a,b,c,d){if(a<=19)return b&c|~b&d;else if(a<=39)return b^c^d;else if(a<=59)return b&c|b&d|c&d;else if(a<=79)return b^c^d},z:function(a,b){return b<<a|b>>>32-a},g:function(a){var b,c,d,e,f,g,h=a.slice(0),i=this.c;c=i[0];d=i[1];e=i[2];f=i[3];g=i[4];for(a=0;a<=79;a++){if(a>=
16)h[a]=this.z(1,h[a-3]^h[a-8]^h[a-14]^h[a-16]);b=this.z(5,c)+this.X(a,d,e,f)+g+h[a]+this.d[Math.floor(a/20)]|0;g=f;f=e;e=this.z(30,d);d=c;c=b}i[0]=i[0]+c|0;i[1]=i[1]+d|0;i[2]=i[2]+e|0;i[3]=i[3]+f|0;i[4]=i[4]+g|0}};sjcl.bn=function(a){this.initWith(a)};
sjcl.bn.prototype={radix:24,maxMul:8,f:sjcl.bn,copy:function(){return new this.f(this)},initWith:function(a){var b=0,c;switch(typeof a){case "object":this.limbs=a.limbs.slice(0);break;case "number":this.limbs=[a];this.normalize();break;case "string":a=a.replace(/^0x/,"");this.limbs=[];c=this.radix/4;for(b=0;b<a.length;b+=c)this.limbs.push(parseInt(a.substring(Math.max(a.length-b-c,0),a.length-b),16));break;default:this.limbs=[0]}return this},equals:function(a){if(typeof a==="number")a=new this.f(a);
var b=0,c;this.fullReduce();a.fullReduce();for(c=0;c<this.limbs.length||c<a.limbs.length;c++)b|=this.getLimb(c)^a.getLimb(c);return b===0},getLimb:function(a){return a>=this.limbs.length?0:this.limbs[a]},greaterEquals:function(a){if(typeof a==="number")a=new this.f(a);var b=0,c=0,d,e,f;for(d=Math.max(this.limbs.length,a.limbs.length)-1;d>=0;d--){e=this.getLimb(d);f=a.getLimb(d);c|=f-e&~b;b|=e-f&~c}return(c|~b)>>>31},toString:function(){this.fullReduce();var a="",b,c,d=this.limbs;for(b=0;b<this.limbs.length;b++){for(c=
d[b].toString(16);b<this.limbs.length-1&&c.length<6;)c="0"+c;a=c+a}return"0x"+a},addM:function(a){if(typeof a!=="object")a=new this.f(a);var b=this.limbs,c=a.limbs;for(a=b.length;a<c.length;a++)b[a]=0;for(a=0;a<c.length;a++)b[a]+=c[a];return this},doubleM:function(){var a,b=0,c,d=this.radix,e=this.radixMask,f=this.limbs;for(a=0;a<f.length;a++){c=f[a];c=c+c+b;f[a]=c&e;b=c>>d}b&&f.push(b);return this},halveM:function(){var a,b=0,c,d=this.radix,e=this.limbs;for(a=e.length-1;a>=0;a--){c=e[a];e[a]=c+b>>
1;b=(c&1)<<d}e[e.length-1]||e.pop();return this},subM:function(a){if(typeof a!=="object")a=new this.f(a);var b=this.limbs,c=a.limbs;for(a=b.length;a<c.length;a++)b[a]=0;for(a=0;a<c.length;a++)b[a]-=c[a];return this},mod:function(a){a=(new sjcl.bn(a)).normalize();for(var b=(new sjcl.bn(this)).normalize(),c=0;b.greaterEquals(a);c++)a.doubleM();for(;c>0;c--){a.halveM();b.greaterEquals(a)&&b.subM(a).normalize()}return b.trim()},inverseMod:function(a){var b=new sjcl.bn(1),c=new sjcl.bn(0),d=new sjcl.bn(this),
e=new sjcl.bn(a),f,g=1;if(!(a.limbs[0]&1))throw new sjcl.exception.invalid("inverseMod: p must be odd");do{if(d.limbs[0]&1){if(!d.greaterEquals(e)){f=d;d=e;e=f;f=b;b=c;c=f}d.subM(e);d.normalize();b.greaterEquals(c)||b.addM(a);b.subM(c)}d.halveM();b.limbs[0]&1&&b.addM(a);b.normalize();b.halveM();for(f=g=0;f<d.limbs.length;f++)g|=d.limbs[f]}while(g);if(!e.equals(1))throw new sjcl.exception.invalid("inverseMod: p and x must be relatively prime");return c},add:function(a){return this.copy().addM(a)},
sub:function(a){return this.copy().subM(a)},mul:function(a){if(typeof a==="number")a=new this.f(a);var b,c=this.limbs,d=a.limbs,e=c.length,f=d.length,g=new this.f,h=g.limbs,i,k=this.maxMul;for(b=0;b<this.limbs.length+a.limbs.length+1;b++)h[b]=0;for(b=0;b<e;b++){i=c[b];for(a=0;a<f;a++)h[b+a]+=i*d[a];if(!--k){k=this.maxMul;g.cnormalize()}}return g.cnormalize().reduce()},square:function(){return this.mul(this)},power:function(a){if(typeof a==="number")a=[a];else if(a.limbs!==undefined)a=a.normalize().limbs;
var b,c,d=new this.f(1),e=this;for(b=0;b<a.length;b++)for(c=0;c<this.radix;c++){if(a[b]&1<<c)d=d.mul(e);e=e.square()}return d},mulmod:function(a,b){return this.mod(b).mul(a.mod(b)).mod(b)},powermod:function(a,b){var c=new sjcl.bn(1),d=new sjcl.bn(this);for(a=new sjcl.bn(a);;){if(a.limbs[0]&1)c=c.mulmod(d,b);a.halveM();if(a.equals(0))break;d=d.mulmod(d,b)}return c.normalize().reduce()},trim:function(){var a=this.limbs,b;do b=a.pop();while(a.length&&b===0);a.push(b);return this},reduce:function(){return this},
fullReduce:function(){return this.normalize()},normalize:function(){var a=0,b,c=this.ipv,d,e=this.limbs,f=e.length,g=this.radixMask;for(b=0;b<f||a!==0&&a!==-1;b++){a=(e[b]||0)+a;d=e[b]=a&g;a=(a-d)*c}if(a===-1)e[b-1]-=this.placeVal;return this},cnormalize:function(){var a=0,b,c=this.ipv,d,e=this.limbs,f=e.length,g=this.radixMask;for(b=0;b<f-1;b++){a=e[b]+a;d=e[b]=a&g;a=(a-d)*c}e[b]+=a;return this},toBits:function(a){this.fullReduce();a=a||this.exponent||this.limbs.length*this.radix;var b=Math.floor((a-
1)/24),c=sjcl.bitArray;a=[c.partial((a+7&-8)%this.radix||this.radix,this.getLimb(b))];for(b--;b>=0;b--)a=c.concat(a,[c.partial(this.radix,this.getLimb(b))]);return a},bitLength:function(){this.fullReduce();for(var a=this.radix*(this.limbs.length-1),b=this.limbs[this.limbs.length-1];b;b>>=1)a++;return a+7&-8}};
sjcl.bn.fromBits=function(a){var b=new this,c=[],d=sjcl.bitArray,e=this.prototype,f=Math.min(this.bitLength||0x100000000,d.bitLength(a)),g=f%e.radix||e.radix;for(c[0]=d.extract(a,0,g);g<f;g+=e.radix)c.unshift(d.extract(a,g,e.radix));b.limbs=c;return b};sjcl.bn.prototype.ipv=1/(sjcl.bn.prototype.placeVal=Math.pow(2,sjcl.bn.prototype.radix));sjcl.bn.prototype.radixMask=(1<<sjcl.bn.prototype.radix)-1;
sjcl.bn.pseudoMersennePrime=function(a,b){function c(g){this.initWith(g)}var d=c.prototype=new sjcl.bn,e,f;e=d.modOffset=Math.ceil(f=a/d.radix);d.exponent=a;d.offset=[];d.factor=[];d.minOffset=e;d.fullMask=0;d.fullOffset=[];d.fullFactor=[];d.modulus=c.modulus=new sjcl.bn(Math.pow(2,a));d.fullMask=0|-Math.pow(2,a%d.radix);for(e=0;e<b.length;e++){d.offset[e]=Math.floor(b[e][0]/d.radix-f);d.fullOffset[e]=Math.ceil(b[e][0]/d.radix-f);d.factor[e]=b[e][1]*Math.pow(0.5,a-b[e][0]+d.offset[e]*d.radix);d.fullFactor[e]=
b[e][1]*Math.pow(0.5,a-b[e][0]+d.fullOffset[e]*d.radix);d.modulus.addM(new sjcl.bn(Math.pow(2,b[e][0])*b[e][1]));d.minOffset=Math.min(d.minOffset,-d.offset[e])}d.f=c;d.modulus.cnormalize();d.reduce=function(){var g,h,i,k=this.modOffset,j=this.limbs,l=this.offset,m=this.offset.length,n=this.factor,o;for(g=this.minOffset;j.length>k;){i=j.pop();o=j.length;for(h=0;h<m;h++)j[o+l[h]]-=n[h]*i;g--;if(!g){j.push(0);this.cnormalize();g=this.minOffset}}this.cnormalize();return this};d.U=d.fullMask===-1?d.reduce:
function(){var g=this.limbs,h=g.length-1,i,k;this.reduce();if(h===this.modOffset-1){k=g[h]&this.fullMask;g[h]-=k;for(i=0;i<this.fullOffset.length;i++)g[h+this.fullOffset[i]]-=this.fullFactor[i]*k;this.normalize()}};d.fullReduce=function(){var g,h;this.U();this.addM(this.modulus);this.addM(this.modulus);this.normalize();this.U();for(h=this.limbs.length;h<this.modOffset;h++)this.limbs[h]=0;g=this.greaterEquals(this.modulus);for(h=0;h<this.limbs.length;h++)this.limbs[h]-=this.modulus.limbs[h]*g;this.cnormalize();
return this};d.inverse=function(){return this.power(this.modulus.sub(2))};c.fromBits=sjcl.bn.fromBits;return c};
sjcl.bn.prime={p127:sjcl.bn.pseudoMersennePrime(127,[[0,-1]]),p25519:sjcl.bn.pseudoMersennePrime(255,[[0,-19]]),p192:sjcl.bn.pseudoMersennePrime(192,[[0,-1],[64,-1]]),p224:sjcl.bn.pseudoMersennePrime(224,[[0,1],[96,-1]]),p256:sjcl.bn.pseudoMersennePrime(0x100,[[0,-1],[96,1],[192,1],[224,-1]]),p384:sjcl.bn.pseudoMersennePrime(384,[[0,-1],[32,1],[96,-1],[128,-1]]),p521:sjcl.bn.pseudoMersennePrime(521,[[0,-1]])};
sjcl.bn.random=function(a,b){if(typeof a!=="object")a=new sjcl.bn(a);for(var c,d,e=a.limbs.length,f=a.limbs[e-1]+1,g=new sjcl.bn;;){do{c=sjcl.random.randomWords(e,b);if(c[e-1]<0)c[e-1]+=0x100000000}while(Math.floor(c[e-1]/f)===Math.floor(0x100000000/f));c[e-1]%=f;for(d=0;d<e-1;d++)c[d]&=a.radixMask;g.limbs=c;if(!g.greaterEquals(a))return g}};sjcl.hash.md5=function(a){this.A[0]||this.r();if(a){this.c=a.c.slice(0);this.b=a.b.slice(0);this.a=a.a}else this.reset()};sjcl.hash.md5.hash=function(a){return(new sjcl.hash.md5).update(a).finalize()};
sjcl.hash.md5.prototype={blockSize:512,reset:function(){this.c=this.l.slice(0);this.b=[];this.a=0;return this},update:function(a){if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);var b,c=this.b=sjcl.bitArray.concat(this.b,a);b=this.a;a=this.a=b+sjcl.bitArray.bitLength(a);for(b=this.blockSize+b&-this.blockSize;b<=a;b+=this.blockSize)this.g(c.splice(0,16),true);return this},finalize:function(){var a,b=this.b,c=this.c;b=sjcl.bitArray.concat(b,[sjcl.bitArray.partial(1,1)]);for(a=b.length+2;a&
15;a++)b.push(0);b.push(this.a|0);for(b.push(this.a/0x100000000|0);b.length;)this.g(b.splice(0,16),b.length);this.reset();this.I(c,4);return c},l:[1732584193,4023233417,2562383102,271733878],I:function(a,b){var c,d;for(c=0;c<b;c++){d=a[c];a[c]=d>>>24|d>>8&0xff00|(d&0xff00)<<8|(d&255)<<24}},A:[],r:function(){var a;for(a=0;a<64;a++)this.A[a]=0x100000000*Math.abs(Math.sin(a+1))|0},g:function(a,b){var c,d,e,f=a.slice(0),g=this.c,h=this.A;a=g[0];c=g[1];d=g[2];e=g[3];this.I(f,b?16:14);for(b=0;b<64;b++){var i,
k,j;if(b<32)if(b<16){i=c&d|~c&e;k=b;j=[7,12,17,22]}else{i=e&c|~e&d;k=(5*b+1)%16;j=[5,9,14,20]}else if(b<48){i=c^d^e;k=(3*b+5)%16;j=[4,11,16,23]}else{i=d^(c|~e);k=7*b%16;j=[6,10,15,21]}i=a+i+f[k]+h[b];a=e;e=d;d=c;c=(i<<j[b%4]|i>>>32-j[b%4])+c|0}g[0]+=a;g[1]+=c;g[2]+=d;g[3]+=e}};
sjcl.misc.hmac_sha1=function(a,b){this.p=b=b||sjcl.hash.sha1;var c=[[],[]],d=b.prototype.blockSize/32;this.e=[new b,new b];if(a.length>d)a=b.hash(a);for(b=0;b<d;b++){c[0][b]=a[b]^909522486;c[1][b]=a[b]^1549556828}this.e[0].update(c[0]);this.e[1].update(c[1])};sjcl.misc.hmac_sha1.prototype.encrypt=sjcl.misc.hmac_sha1.prototype.mac=function(a,b){a=(new this.p(this.e[0])).update(a,b).finalize();return(new this.p(this.e[1])).update(a).finalize()};
sjcl.misc.pbkdf2=function(a,b,c,d,e){c=c||1E3;if(d<0||c<0)throw sjcl.exception.invalid("invalid params to pbkdf2");if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);e=e||sjcl.misc.hmac;a=new e(a);var f,g,h,i,k=[],j=sjcl.bitArray;for(i=1;32*k.length<(d||1);i++){e=f=a.encrypt(j.concat(b,[i]));for(g=1;g<c;g++){f=a.encrypt(f);for(h=0;h<f.length;h++)e[h]^=f[h]}k=k.concat(e)}if(d)k=j.clamp(k,d);return k};
sjcl.random={randomWords:function(a,b){var c=[];b=this.isReady(b);var d;if(b===0)throw new sjcl.exception.notReady("generator isn't seeded");else b&2&&this.$(!(b&1));for(b=0;b<a;b+=4){(b+1)%0x10000===0&&this.R();d=this.F();c.push(d[0],d[1],d[2],d[3])}this.R();return c.slice(0,a)},setDefaultParanoia:function(a){this.D=a},addEntropy:function(a,b,c){c=c||"user";var d,e,f=(new Date).valueOf(),g=this.w[c],h=this.isReady();d=this.L[c];if(d===undefined)d=this.L[c]=this.W++;if(g===undefined)g=this.w[c]=0;this.w[c]=
(this.w[c]+1)%this.h.length;switch(typeof a){case "number":break;case "object":if(b===undefined)for(c=b=0;c<a.length;c++)for(e=a[c];e>0;){b++;e>>>=1}this.h[g].update([d,this.P++,2,b,f,a.length].concat(a));break;case "string":if(b===undefined)b=a.length;this.h[g].update([d,this.P++,3,b,f,a.length]);this.h[g].update(a);break;default:throw new sjcl.exception.bug("random: addEntropy only supports number, array or string");}this.q[g]+=b;this.m+=b;if(h===0){this.isReady()!==0&&this.Q("seeded",Math.max(this.n,
this.m));this.Q("progress",this.getProgress())}},isReady:function(a){a=this.J[a!==undefined?a:this.D];return this.n&&this.n>=a?this.q[0]>80&&(new Date).valueOf()>this.S?3:1:this.m>=a?2:0},getProgress:function(a){a=this.J[a?a:this.D];return this.n>=a?1["0"]:this.m>a?1["0"]:this.m/a},startCollectors:function(){if(!this.s){if(window.addEventListener){window.addEventListener("load",this.t,false);window.addEventListener("mousemove",this.u,false)}else if(document.attachEvent){document.attachEvent("onload",
this.t);document.attachEvent("onmousemove",this.u)}else throw new sjcl.exception.bug("can't attach event");this.s=true}},stopCollectors:function(){if(this.s){if(window.removeEventListener){window.removeEventListener("load",this.t,false);window.removeEventListener("mousemove",this.u,false)}else if(window.detachEvent){window.detachEvent("onload",this.t);window.detachEvent("onmousemove",this.u)}this.s=false}},addEventListener:function(a,b){this.B[a][this.V++]=b},removeEventListener:function(a,b){var c;
a=this.B[a];var d=[];for(c in a)a.hasOwnProperty(c)&&a[c]===b&&d.push(c);for(b=0;b<d.length;b++){c=d[b];delete a[c]}},h:[new sjcl.hash.sha256],q:[0],G:0,w:{},P:0,L:{},W:0,n:0,m:0,S:0,d:[0,0,0,0,0,0,0,0],j:[0,0,0,0],C:undefined,D:6,s:false,B:{progress:{},seeded:{}},V:0,J:[0,48,64,96,128,192,0x100,384,512,768,1024],F:function(){for(var a=0;a<4;a++){this.j[a]=this.j[a]+1|0;if(this.j[a])break}return this.C.encrypt(this.j)},R:function(){this.d=this.F().concat(this.F());this.C=new sjcl.cipher.aes(this.d)},
Z:function(a){this.d=sjcl.hash.sha256.hash(this.d.concat(a));this.C=new sjcl.cipher.aes(this.d);for(a=0;a<4;a++){this.j[a]=this.j[a]+1|0;if(this.j[a])break}},$:function(a){var b=[],c=0,d;this.S=b[0]=(new Date).valueOf()+3E4;for(d=0;d<16;d++)b.push(Math.random()*0x100000000|0);for(d=0;d<this.h.length;d++){b=b.concat(this.h[d].finalize());c+=this.q[d];this.q[d]=0;if(!a&&this.G&1<<d)break}if(this.G>=1<<this.h.length){this.h.push(new sjcl.hash.sha256);this.q.push(0)}this.m-=c;if(c>this.n)this.n=c;this.G++;
this.Z(b)},u:function(a){sjcl.random.addEntropy([a.x||a.clientX||a.offsetX,a.y||a.clientY||a.offsetY],2,"mouse")},t:function(){sjcl.random.addEntropy(new Date,2,"loadtime")},Q:function(a,b){var c;a=sjcl.random.B[a];var d=[];for(c in a)a.hasOwnProperty(c)&&d.push(a[c]);for(c=0;c<d.length;c++)d[c](b)}};try{var s=new Uint32Array(32);crypto.getRandomValues(s);sjcl.random.addEntropy(s,1024,"crypto['getRandomValues']")}catch(t){}
sjcl.json={defaults:{v:1,iter:1E3,ks:128,ts:64,mode:"ccm",adata:"",cipher:"aes"},encrypt:function(a,b,c,d){c=c||{};d=d||{};var e=sjcl.json,f=e.i({iv:sjcl.random.randomWords(4,0)},e.defaults);e.i(f,c);if(typeof f.salt==="string")f.salt=sjcl.codec.base64.toBits(f.salt);if(typeof f.iv==="string")f.iv=sjcl.codec.base64.toBits(f.iv);if(!sjcl.mode[f.mode]||!sjcl.cipher[f.cipher]||typeof a==="string"&&f.iter<=100||f.ts!==64&&f.ts!==96&&f.ts!==128||f.ks!==128&&f.ks!==192&&f.ks!==0x100||f.iv.length<2||f.iv.length>
4)throw new sjcl.exception.invalid("json encrypt: invalid parameters: "+JSON.stringify(f));if(typeof a==="string"){c=sjcl.misc.cachedPbkdf2(a,f);a=c.key.slice(0,f.ks/32);f.salt=c.salt}if(typeof b==="string")b=sjcl.codec.utf8String.toBits(b);c=new sjcl.cipher[f.cipher](a);e.i(d,f);d.key=a;f.ct=sjcl.mode[f.mode].encrypt(c,b,f.iv,f.adata,f.ts);return e.encode(e.aa(f,e.defaults))},decrypt:function(a,b,c,d){c=c||{};d=d||{};var e=sjcl.json;b=e.i(e.i(e.i({},e.defaults),e.decode(b)),c,true);if(typeof b.salt===
"string")b.salt=sjcl.codec.base64.toBits(b.salt);if(typeof b.iv==="string")b.iv=sjcl.codec.base64.toBits(b.iv);if(!sjcl.mode[b.mode]||!sjcl.cipher[b.cipher]||typeof a==="string"&&b.iter<=100||b.ts!==64&&b.ts!==96&&b.ts!==128||b.ks!==128&&b.ks!==192&&b.ks!==0x100||!b.iv||b.iv.length<2||b.iv.length>4)throw new sjcl.exception.invalid("json decrypt: invalid parameters");if(typeof a==="string"){c=sjcl.misc.cachedPbkdf2(a,b);a=c.key.slice(0,b.ks/32);b.salt=c.salt}c=new sjcl.cipher[b.cipher](a);c=sjcl.mode[b.mode].decrypt(c,
b.ct,b.iv,b.adata,b.ts);e.i(d,b);d.key=a;return sjcl.codec.utf8String.fromBits(c)},encode:function(a){var b,c="{",d="";for(b in a)if(a.hasOwnProperty(b)){if(!b.match(/^[a-z0-9]+$/i))throw new sjcl.exception.invalid("json encode: invalid property name");c+=d+b+":";d=",";switch(typeof a[b]){case "number":case "boolean":c+=a[b];break;case "string":c+='"'+escape(a[b])+'"';break;case "object":c+='"'+sjcl.codec.base64.fromBits(a[b],1)+'"';break;default:throw new sjcl.exception.bug("json encode: unsupported type");
}}return c+"}"},decode:function(a){a=a.replace(/\s/g,"");if(!a.match(/^\{.*\}$/))throw new sjcl.exception.invalid("json decode: this isn't json: "+a);a=a.replace(/^\{|\}$/g,"").split(/,/);var b={},c,d;for(c=0;c<a.length;c++){if(!(d=a[c].match(/^([a-z][a-z0-9]*):(?:(\d+)|"([a-z0-9+\/%*_.@=\-]*)")$/i)))throw new sjcl.exception.invalid("json decode: this isn't json!");b[d[1]]=d[2]?parseInt(d[2],10):d[1].match(/^(ct|salt|iv)$/)?sjcl.codec.base64.toBits(d[3]):unescape(d[3])}return b},i:function(a,b,c){if(a===
undefined)a={};if(b===undefined)return a;var d;for(d in b)if(b.hasOwnProperty(d)){if(c&&a[d]!==undefined&&a[d]!==b[d])throw new sjcl.exception.invalid("required parameter overridden");a[d]=b[d]}return a},aa:function(a,b){var c={},d;for(d in a)if(a.hasOwnProperty(d)&&a[d]!==b[d])c[d]=a[d];return c},ba:function(a,b){var c={},d;for(d=0;d<b.length;d++)if(a[b[d]]!==undefined)c[b[d]]=a[b[d]];return c}};sjcl.encrypt=sjcl.json.encrypt;sjcl.decrypt=sjcl.json.decrypt;sjcl.misc.Y={};
sjcl.misc.cachedPbkdf2=function(a,b){var c=sjcl.misc.Y,d;b=b||{};d=b.iter||1E3;c=c[a]=c[a]||{};d=c[d]=c[d]||{firstSalt:b.salt&&b.salt.length?b.salt.slice(0):sjcl.random.randomWords(2,0)};c=b.salt===undefined?d.firstSalt:b.salt;d[c]=d[c]||sjcl.misc.pbkdf2(a,c,b.iter);return{key:d[c].slice(0),salt:c.slice(0)}};
sjcl.mode.cbc={name:"cbc",encrypt:function(a,b,c,d){if(d&&d.length)throw new sjcl.exception.invalid("cbc can't authenticate data");if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("cbc iv must be 128 bits");var e=sjcl.bitArray,f=e.k,g=e.bitLength(b),h=0,i=[];if(g&7)throw new sjcl.exception.invalid("pkcs#5 padding only works for multiples of a byte");for(d=0;h+128<=g;d+=4,h+=128){c=a.encrypt(f(c,b.slice(d,d+4)));i.splice(d,0,c[0],c[1],c[2],c[3])}g=(16-(g>>3&15))*0x1010101;c=a.encrypt(f(c,
e.concat(b,[g,g,g,g]).slice(d,d+4)));i.splice(d,0,c[0],c[1],c[2],c[3]);return i},decrypt:function(a,b,c,d){if(d&&d.length)throw new sjcl.exception.invalid("cbc can't authenticate data");if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("cbc iv must be 128 bits");if(sjcl.bitArray.bitLength(b)&127||!b.length)throw new sjcl.exception.corrupt("cbc ciphertext must be a positive multiple of the block size");var e=sjcl.bitArray,f=e.k,g,h=[];for(d=0;d<b.length;d+=4){g=b.slice(d,d+4);c=
f(c,a.decrypt(g));h.splice(d,0,c[0],c[1],c[2],c[3]);c=g}g=h[d-1]&255;if(g==0||g>16)throw new sjcl.exception.corrupt("pkcs#5 padding corrupt");c=g*0x1010101;if(!e.equal(e.bitSlice([c,c,c,c],0,g*8),e.bitSlice(h,h.length*32-g*8,h.length*32)))throw new sjcl.exception.corrupt("pkcs#5 padding corrupt");return e.bitSlice(h,0,h.length*32-g*8)}};
var g=!0,i=null,l=!1,Cc=require("chrome").Cc,Ci=require("chrome").Ci,aa=Cc["@mozilla.org/storage/service;1"].getService(Ci.mozIStorageService);function WebDatabase(a,b,c){this.description=c;b=Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("ProfD",Ci.nsIFile);b.append("..");b.append(a+".sqlite");(this.j=aa.openDatabase(b))||console&&console.error("[SQLITE] Couldn't connect to database.")}
WebDatabase.prototype.readTransaction=WebDatabase.prototype.transaction=function(a,b,c){b=new n(this.j,b,c);try{a(b)}catch(d){console&&console.error("[SQLITE] Transaction failed: "+d)}};function n(a,b,c){this.j=a;this.error=i;this.f=b;this.q=c;this.J=[];this.b=i}n.prototype.queueStatement=function(a,b,c,d){this.J.push({Wa:a,Pa:b,q:c,f:d})};
n.prototype.processNextStatementInQueue=function(){if(this.error)this.f&&this.f(this.error);else if(0==this.J.length)this.q&&this.q(this);else{this.b=this.J.shift();try{this.executeSqlStatement(this.b.Wa,this.b.Pa,this.b.q,this.b.f)}catch(a){this.b.f&&this.b.f()}}};
n.prototype.executeSqlStatement=function(a,b,c,d){var e=this.j.createStatement(a);if(b)for(a=0;a<b.length;++a)e.bindByIndex(a,b[a]);var f=this,h={rows:{item:function(a){return this.L[a]},L:[],length:0}};e.executeAsync({handleResult:function(a){f.processResults(a,e,h)},handleError:function(a){console.error("[SQLITE] handleError: "+a.message);d&&d(f,a);f.error=a;f.b=i;f.processNextStatementInQueue()},handleCompletion:function(a){a!=Ci.mozIStorageStatementCallback.REASON_FINISHED&&console&&console.error("[SQLITE] Query canceled or aborted!");
c&&c(f,h);f.b=i;f.processNextStatementInQueue()}})};n.prototype.executeSql=function(a,b,c,d){this.queueStatement(a,b,c,d);this.b==i&&this.processNextStatementInQueue()};n.prototype.processResults=function(a,b,c){try{for(var d=a.getNextRow();d;){for(var e={},f=0;f<d.numEntries;++f)e[b.getColumnName(f)]=d.getResultByIndex(f);c.rows.L.push(e);c.rows.length+=1;d=a.getNextRow()}}catch(h){o(h)}};var q=require("timer");setTimeout=q.setTimeout;clearTimeout=q.clearTimeout;setInterval=q.setInterval;
clearInterval=q.clearInterval;var hiddenFrames=require("hidden-frame"),WebSocket=i;hiddenFrames.add(hiddenFrames.HiddenFrame({onReady:function(){this.element.contentWindow.location=require("self").data.url("ui/popup.html");WebSocket=this.element.contentWindow.MozWebSocket}}));
var ba={ga:function(a){for(var b=[0,1996959894,3993919788,2567524794,124634137,1886057615,3915621685,2657392035,249268274,2044508324,3772115230,2547177864,162941995,2125561021,3887607047,2428444049,498536548,1789927666,4089016648,2227061214,450548861,1843258603,4107580753,2211677639,325883990,1684777152,4251122042,2321926636,335633487,1661365465,4195302755,2366115317,997073096,1281953886,3579855332,2724688242,1006888145,1258607687,3524101629,2768942443,901097722,1119000684,3686517206,2898065728,853044451,
1172266101,3705015759,2882616665,651767980,1373503546,3369554304,3218104598,565507253,1454621731,3485111705,3099436303,671266974,1594198024,3322730930,2970347812,795835527,1483230225,3244367275,3060149565,1994146192,31158534,2563907772,4023717930,1907459465,112637215,2680153253,3904427059,2013776290,251722036,2517215374,3775830040,2137656763,141376813,2439277719,3865271297,1802195444,476864866,2238001368,4066508878,1812370925,453092731,2181625025,4111451223,1706088902,314042704,2344532202,4240017532,
1658658271,366619977,2362670323,4224994405,1303535960,984961486,2747007092,3569037538,1256170817,1037604311,2765210733,3554079995,1131014506,879679996,2909243462,3663771856,1141124467,855842277,2852801631,3708648649,1342533948,654459306,3188396048,3373015174,1466479909,544179635,3110523913,3462522015,1591671054,702138776,2966460450,3352799412,1504918807,783551873,3082640443,3233442989,3988292384,2596254646,62317068,1957810842,3939845945,2647816111,81470997,1943803523,3814918930,2489596804,225274430,
2053790376,3826175755,2466906013,167816743,2097651377,4027552580,2265490386,503444072,1762050814,4150417245,2154129355,426522225,1852507879,4275313526,2312317920,282753626,1742555852,4189708143,2394877945,397917763,1622183637,3604390888,2714866558,953729732,1340076626,3518719985,2797360999,1068828381,1219638859,3624741850,2936675148,906185462,1090812512,3747672003,2825379669,829329135,1181335161,3412177804,3160834842,628085408,1382605366,3423369109,3138078467,570562233,1426400815,3317316542,2998733608,
733239954,1555261956,3268935591,3050360625,752459403,1541320221,2607071920,3965973030,1969922972,40735498,2617837225,3943577151,1913087877,83908371,2512341634,3803740692,2075208622,213261112,2463272603,3855990285,2094854071,198958881,2262029012,4057260610,1759359992,534414190,2176718541,4139329115,1873836001,414664567,2282248934,4279200368,1711684554,285281116,2405801727,4167216745,1634467795,376229701,2685067896,3608007406,1308918612,956543938,2808555105,3495958263,1231636301,1047427035,2932959818,
3654703836,1088359270,936918E3,2847714899,3736837829,1202900863,817233897,3183342108,3401237130,1404277552,615818150,3134207493,3453421203,1423857449,601450431,3009837614,3294710456,1567103746,711928724,3020668471,3272380065,1510334235,755167117],c=-1,d=0;d<a.length;d++)c=c>>>8^b[(c^a[d])&255]&4294967295;c=~c;0>c&&(c+=4294967296);return 0==c?1:c}},ca="UnlockPasswordAccepted",u="UnlockPasswordRejected",x="UnlockDataNotAvailable",da="UnlockAgentNotConnected",fa="UnlockAgentIsSyncing",ga="UnlockPasswordUnknownError";
function ha(a){var b="";return b="object"==typeof safari?safari.extension.baseURI+a:"object"==typeof chrome?chrome.extension.getURL(a):require("self").data.url(a)}function o(a){console.error("Exception caught:\n  name: %s\n  type: %s\n  message: %s\n  stack: %s\n  %s:%s",a.name,a.type,a.message,a.stack,a.sourceURL,a.line);console.error("Exception: "+JSON.stringify(a))}function ia(a){return(a=a.match(/(.*?:\/\/(.[^/]+))/))?a[1]:""}var ja=150;
function ka(a){for(var b=[],c=0,d=a.length;c<d;c++)b.push(ja^a.charCodeAt(c));return b}function z(a){if(!a)return"";for(var b="",c=0,d=a.length;c<d;c++)b+=String.fromCharCode(ja^a[c]);return b}
var la={m:function(){function a(){return(65536*(1+Math.random())|0).toString(16).substring(1).toUpperCase()}return[a(),a(),a(),a(),a(),a(),a(),a()].join("")}},B=function(){function a(a,b){var d=sjcl.random.randomWords(2,0),t=h(a,d),d=sjcl.bitArray.concat(j,d),t=e(t.key,t.iv,b),t=sjcl.bitArray.concat(d,t);return c(t)}function b(a,c){var b=d(c),t=sjcl.bitArray.bitSlice(b,0,64),e=p;sjcl.bitArray.equal(t,j)&&(e=sjcl.bitArray.bitSlice(b,64,128),b=sjcl.bitArray.bitSlice(b,128));t=h(a,e);return f(t.key,
t.iv,b)}function c(a){return sjcl.codec.base64.fromBits(a)}function d(a){return sjcl.codec.base64.toBits(a.replace("\x00",""))}function e(a,c,b){try{var d=new sjcl.cipher.aes(a);return sjcl.mode.cbc.encrypt(d,b,c,i)}catch(e){console.error("[CRYPTO] Failed to encrypt: "+e.message)}}function f(a,c,b){try{var d=new sjcl.cipher.aes(a);return sjcl.mode.cbc.decrypt(d,b,c,i)}catch(e){console.error("[CRYPTO] Failed to decrypt: "+e.message)}}function h(a,c){c||(c=p);var b=i,b=0<c.length?sjcl.bitArray.concat(a,
c):a,d=sjcl.hash.md5.hash(b),e=sjcl.hash.md5.hash(sjcl.bitArray.concat(d,b)),b=sjcl.hash.md5.hash(sjcl.bitArray.concat(e,b));return{key:sjcl.bitArray.concat(d,e),iv:b}}var j=sjcl.codec.bytes.toBits([83,97,108,116,101,100,95,95]),p=sjcl.codec.bytes.toBits([0,0,0,0,0,0,0,0]),m=sjcl.codec.utf8String.toBits("dpGHuBcGmKaQfVEvFmd1M6eFpmFuNL");return{Ab:function(c){return!c?i:a(m,sjcl.codec.utf8String.toBits(c))},wa:function(a){if(!a)return i;a=b(m,a);return sjcl.codec.utf8String.fromBits(a)},openSSLKey:h,
la:d,na:c,C:b,D:a,ha:function(a,c,b){var b=d(b),e=sjcl.bitArray.bitSlice(b,0,64),w=p;sjcl.bitArray.equal(e,j)&&(w=sjcl.bitArray.bitSlice(b,64,128),b=sjcl.bitArray.bitSlice(b,128));c=sjcl.misc.pbkdf2(a,w,c,384,sjcl.misc.hmac_sha1);a=sjcl.bitArray.bitSlice(c,0,256);c=sjcl.bitArray.bitSlice(c,256);return f(a,c,b)},va:f,ya:e}}();function ma(a){this.V=a}
ma.prototype={gb:function(){return this.V.secureContents||{}},R:function(){return this.gb().fields},za:function(a){var b=this.R();if(!b)return i;for(var c=0;c<b.length;++c){var d=b[c];if(d.designation===a)return d}return i},location:function(){return this.V.overview.location},F:function(){var a=this.za("password");return a?a.value:""},Aa:function(a){var b=this.R();if(!b)return[];for(var c=[],d=0;d<b.length;++d){var e=b[d].type;e&&0<=a.indexOf(e)&&c.push(b[d])}return c},Qa:function(){return this.Aa(["P"])}};
var D=function(){function a(a){a||(a=[]);try{m=a;var c=sjcl.encrypt("S7BQMkwBJRsrQVb}Zjz9BJS+xuOIhaad",a.join("\n"),p);f("doNotAutosaveOn",c)}catch(b){console.error("[SETTINGS] Failed to setDoNotAutosaveOnDomains: "+b.message)}}function b(){if(m)return m;var a=j("doNotAutosaveOn",i);if(!a)return m=[];try{var c=sjcl.decrypt("S7BQMkwBJRsrQVb}Zjz9BJS+xuOIhaad",a,p);return m=c?c.split("\n"):[]}catch(b){return console.error("[SETTINGS] Failed to decrypt"),m=[]}}function c(a){k=e(a);try{var c=JSON.stringify(a),
b=sjcl.encrypt("S7BQMkwBJRsrQVb}Zjz9BJS+xuOIhaad",c,p);f("domainRules",b)}catch(d){console.error("[SETTINGS] Failed to setDomainRules: "+d.message)}}function d(){return e([{match:".*\\.apple\\.com$",result:"apple.com"},{match:".*\\.smile\\.co\\.uk$",result:"smile.co.uk"},{match:".*\\.google\\.com$",result:"google.com"},{match:".*\\.yahoo\\.com$",result:"yahoo.com"},{match:".*\\.fidelity\\.com$",result:"fidelity.com"},{match:".*\\.(td|tdcanadatrust)\\.com$",result:"td.com"},{match:".*\\.(dropbox|getdropbox)\\.com$",
result:"dropbox.com"},{match:".*\\.(citi|citibank|citicards)\\.com$",result:"citi.com"},{match:".*\\.(live|passport|msn|hotmail|microsoft)\\.com$",result:"microsoft.com"},{match:".*\\.(37signals|basecamphq|backpackit|campfirenow|highrisehq)\\.com$",result:"37signals.com"},{match:"(.*\\.)?(agile\\.ws|agilewebsolutions\\.com)$",result:"$1agilebits.com"}])}function e(a){if(!a)return[];var c=[];try{for(var b=0;b<a.length;++b){var d=a[b].match,y=a[b].result;d&&y&&c.push({match:RegExp(d),result:y})}}catch(e){console.error("[SETTINGS] Failed to parse domain rules: "+
e.message)}return c}function f(a,c){"object"==typeof chrome?localStorage[a]=c:"object"==typeof safari?safari.extension.settings[a]=c:"object"==typeof na?na[a]=c:console.log("[SETTINGS] Failed to setValue")}function h(a,c){var b=j(a);return"number"==typeof b?b:b?parseInt(b,10):c}function j(a,c){var b=i;"object"==typeof chrome?b=localStorage[a]:"object"==typeof safari?b=safari.extension.settings[a]:"object"==typeof na?b=na[a]:console.log("[SETTINGS] Failed to getValue");return b?b:c}var p={v:1,iter:105,
ks:128,ts:64,mode:"cbc",cipher:"aes"},m=i,k=i;return{xb:j,getString:j,wb:h,setValue:f,Ca:function(){if(k)return k;try{var a=j("domainRules",i);if(a){var c=sjcl.decrypt("S7BQMkwBJRsrQVb}Zjz9BJS+xuOIhaad",a,p);k=e(JSON.parse(c))}else return k=d()}catch(b){console.error("[SETTINGS] Failed to getDomainRules, going to use defaults. Error: "+b.message),k=d()}0==k.length&&(k=d());return k},Cb:c,getAll:function(){var a={};a.autosave=j("autosave")||"Y";a.autosubmit=j("autosubmit")||"Y";return a},ba:function(a){a.autosave&&
f("autosave",a.autosave);a.autosubmit&&f("autosubmit",a.autosubmit);a.domainRules&&c(a.domainRules)},K:function(){return"N"!=j("universalUnlock")},ca:function(a){var c={};c.autosubmit="Y"==j("autosubmit","Y");if("N"!=j("autosave","Y"))a:{for(var a=C.Q(a),d=C.W(a),e=b(),y=0;y<e.length;++y){var f=e[y];if(f===a||f===d){a=l;break a}}a=g}else a=l;c.autosave=a;return c},d:function(){var a={};a.autosave="N"!=j("autosave");a.autosubmit="N"!=j("autosubmit");a.universalUnlock="N"!=j("universalUnlock");a.concealPasswords=
"N"!=j("concealPasswords");a.tabUsedForGoAndFill=j("tabUsedForGoAndFill")||"NewTab";a.doNotAutosaveOnDomains=b().join("\n");return a},ib:function(c){f("autosave",c.autosave?"Y":"N");f("autosubmit",c.autosubmit?"Y":"N");f("universalUnlock",c.universalUnlock?"Y":"N");f("concealPasswords",c.concealPasswords?"Y":"N");f("tabUsedForGoAndFill",c.tabUsedForGoAndFill);a(c.doNotAutosaveOnDomains.split("\n"))},Da:function(){var a={};a.type=j("password_type","random");a.length=h("password_length",14);a.symbols=
h("password_symbols",0);a.digits=h("password_digits",2);a.avoidAmb=h("password_avoidAmb",1)?g:l;a.allowRepeats=h("password_allowRepeats",1)?g:l;a.separator=j("password_separator","-");return a},hb:function(a){a&&(f("password_type",a.type),f("password_length",""+a.length),f("password_symbols",""+a.symbols),f("password_digits",""+a.digits),f("password_avoidAmb",""+(a.avoidAmb?1:0)),f("password_allowRepeats",""+(a.allowRepeats?1:0)),f("password_separator",a.separator))},Oa:function(c){for(var c=C.Q(c),
c=C.W(c),d=b(),e=0,f=d.length;e<f;e++)if(d[e]==c)return;d.push(c);a(d)},l:function(){f("autosave","N")}}}();function ra(a){for(var b=D.Ca(),c=0;c<b.length;++c){var d=b[c].match;if(d.test(a)){a=a.replace(d,b[c].result);break}}return a}function sa(a){var b=a.match(/^(?:f|ht)tp(?:s)?:\/\/([^/:]+)/im);return b?b[1].toString().toLowerCase():a}function ta(a){if(""==a)return"0000";if(!a)return i;a=sa(a);a=ra(a);return SHA256.sha256_digest(C.z()+a)}
function ua(a){for(var b=a,c=".com,.edu,.gov,.mil,.net,.org,.co.uk".split(","),d=0,e=c.length;d<e;d++){var f=c[d];if(a.substr(-f.length)===f){a=a.substr(0,a.length-f.length);b=a.substring(a.lastIndexOf(".")+1)+f;break}}return b}function G(a){if(""==a)return"0000";if(!a)return i;a=sa(a);if(!a||0==a.length)return"";a=ra(a);a=ua(a);return SHA256.sha256_digest(C.z()+a)}
var H=function(){function a(a,c,b){try{var d=B.wa(c);return B.ha(d,b,a)}catch(e){return console.log("Error during decryption: %s",e),i}}var b=i,c=i,d=i,e=i,f=i,h=i,j=i,p=i,m=i;return{t:function(a,r,f,t,w){b=a;c=r;d=f;w=parseInt(w||"0",10);1E3>w&&(w=1E3);e=w},z:function(){return b},B:function(){return m},sb:function(b){try{var r;var A=a(d,b,e);if(A)if(f=B.C(A,c)){h=A;var t=B.openSSLKey(f,[]);j=t.key;p=t.iv;r=g}else r=i;else r=i;r&&(m=b);return r}catch(w){return l}},r:function(a){a=B.va(j,p,B.la(a));
a=sjcl.codec.utf8String.fromBits(a);return JSON.parse(a)},P:function(a){a=B.ya(j,p,sjcl.codec.utf8String.toBits(a));return B.na(a)},N:function(a){var c;try{var b=B.C(h,a);c=JSON.parse(sjcl.codec.utf8String.fromBits(b))}catch(d){console.error("[KEYCHAIN] Failed to decrypt: "+d.message),c=i}return c},xa:function(a){return B.D(h,sjcl.codec.utf8String.toBits(a))},a:function(){return h==i},tb:a,lock:function(){m=p=j=f=h=i}}}(),C=function(){function a(a){var c={uuid:a.uuid,type_name:a.type_name,overview:a.overview,
details:a.details,trashed:a.trashed,created_at:a.created_at,updated_at:a.updated_at,contents_hash:a.contents_hash};a.scope&&(c.scope=a.scope);a.derived_hash&&(c.derived_hash=a.derived_hash);a.naked_hash&&(c.naked_hash=a.naked_hash);a.autosave_token&&(c.autosave_token=a.autosave_token);a.folder_uuid&&(c.folder_uuid=a.folder_uuid);return c}function b(a,c){a.executeSql("SELECT uuid, overview_key, details_key, validation, iterations FROM keys",[],function(a,b){if(1==b.rows.length){var d=b.rows.item(0);
c.key={uuid:d.uuid,overview_key:d.overview_key,details_key:d.details_key,validation:d.validation,iterations:d.iterations}}else 0==b.rows.length?console.warn("[DATASOURCE] Warning: no key found in keys table."):console.warn("[DATASOURCE] Warning: more than one key found in keys table.")})}function c(a){m||(m=g,e.transaction(function(a){a.executeSql("CREATE TABLE IF NOT EXISTS keys (uuid TEXT PRIMARY KEY, overview_key TEXT, details_key TEXT, validation TEXT, iterations INTEGER)",[]);a.executeSql("CREATE TABLE IF NOT EXISTS domain_rules (id INTEGER PRIMARY KEY, match TEXT, result TEXT)",
[]);a.executeSql("CREATE TABLE IF NOT EXISTS items (uuid TEXT PRIMARY KEY, type_name TEXT, overview TEXT, derived_hash TEXT, naked_hash TEXT, details TEXT, scope TEXT, trashed TEXT, created_at INTEGER, updated_at INTEGER, contents_hash TEXT, autosave_token TEXT, folder_uuid TEXT)",[]);a.executeSql("CREATE INDEX IF NOT EXISTS items_type_name_index on items (type_name, trashed)",[]);a.executeSql("CREATE TABLE IF NOT EXISTS config (name TEXT PRIMARY KEY, value TEXT, source TEXT)",[]);a.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",
["buildnum","5"]);a.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["version","3.8.8"]);a.executeSql("INSERT OR IGNORE INTO config (name, value) VALUES (?, ?)",["uuid",f]);a.executeSql("INSERT OR IGNORE INTO config (name, value) VALUES (?, ?)",["created_at",j])},function(a){console.error("Failed to initialize the database: "+a)},function(){a&&a(f)}))}function d(a,b){console.log("[DATASOURCE] Database version: "+a);5>a?(console.log("[DATASOURCE] Upgrading database from "+a),
e.transaction(function(c){4>a&&(c.executeSql("DROP TABLE IF EXISTS config"),c.executeSql("DROP TABLE IF EXISTS items"),c.executeSql("DROP TABLE IF EXISTS keys"));5>a&&(c.executeSql("ALTER TABLE items ADD COLUMN autosave_token TEXT"),c.executeSql("ALTER TABLE items ADD COLUMN folder_uuid TEXT"),c.executeSql("DELETE FROM config WHERE name = 'uuid'"),f="dcd654f0bfd811e0962b0800200c9a66"+la.m())},function(a){console.error("[DATASOURCE] Failed to upgrade database: %s",a?a.message:"unknown");c(b)},function(){c(b)})):
c(b)}var e=i,f="dcd654f0bfd811e0962b0800200c9a66"+la.m(),h=i,j=(new Date).getTime()+"",p=i,m=l,k=i;return{t:function(a){if(e==i){e=new WebDatabase("OnePassword","1.0","1Password Database");var b=-1;e.readTransaction(function(d){d.executeSql("SELECT name, value FROM config WHERE name in ('buildnum', 'uuid', 'version', 'created_at', 'server_database_id')",[],function(a,c){for(var d=0;d<c.rows.length;++d){var e=c.rows.item(d);"uuid"==e.name?f=e.value:"buildnum"==e.name?b=e.value:"version"==e.name?h=
e.value:"created_at"==e.name?j=e.value:"server_database_id"==e.name&&(k=e.value)}},function(){c(a);b=0});d.executeSql("SELECT uuid FROM keys",[],function(a,c){for(var b=0;b<c.rows.length;++b)p=c.rows.item(b).uuid},function(){c(a);b=0})},function(){c(a)},function(){0<b?d(b,a):0>b&&c(a)})}},Va:function(){return h},ua:function(){return j},Ma:function(a){if(!e&&a)a({error:"Extension database not available. Please press Command-Option-Q to restart your browser and discard invalid state."});else{var c=
{};e.readTransaction(function(a){b(a,c)},function(c){c="Database error 1: "+(c?c.message:c);console.error(c);0<c.indexOf(" is prohibited")&&(c="Please restart Safari with Cmd-Option-Q or disable-enable 1Password extension in Safari > Preferences > Extensions.<br><br><small>(Private Browsing mode bug)</small>");a&&a({error:c})},function(){a&&a(c)})}},bb:function(a,c){e.transaction(function(c){c.executeSql("DELETE FROM keys",[]);c.executeSql("INSERT OR REPLACE INTO keys (uuid, overview_key, details_key, validation, iterations) values (?, ?, ?, ?, ?)",
[a.uuid,a.overview_key,a.details_key,a.validation,a.iterations])},function(a){console.error("[DATASOURCE] Database error (saveEncryptionKey):"+(a?a.message:a));c&&c({error:a?a.message:a})},function(){p=a.uuid;c&&c()})},Q:sa,W:ua,ub:ta,zb:G,cb:function(a,c){e.transaction(function(c){a.scope==i&&(a.scope="Regular");c.executeSql("INSERT OR REPLACE INTO items (uuid, type_name, overview, derived_hash, naked_hash, details, scope, trashed, created_at, updated_at, contents_hash, autosave_token, folder_uuid) values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)",
[a.uuid,a.type_name,a.overview,a.derived_hash,a.naked_hash,a.details,a.scope,a.trashed,a.created_at,a.updated_at,a.contents_hash,a.autosave_token,a.folder_uuid]);c.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["checksum","0"])},function(a){console.error("[DATASOURCE] Database error (saveItem):"+(a?a.message:a));c&&c({error:a?a.message:a})},function(){c&&c()})},pb:function(c,d,f,w){var y={items:[]};e.transaction(function(e){for(var s=0;s<c.length;++s){var v=c[s];e.executeSql("INSERT OR REPLACE INTO items (uuid, type_name, overview, derived_hash, naked_hash, details, scope, trashed, created_at, updated_at, contents_hash, autosave_token, folder_uuid) values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)",
[v.uuid,v.type_name,v.overview,v.derived_hash,v.naked_hash,v.details,v.scope,v.trashed,v.created_at,v.updated_at,v.contents_hash,v.autosave_token,v.folder_uuid])}for(s=0;s<d.length;++s)e.executeSql("DELETE FROM items WHERE uuid=?",[d[s]]);b(e,y);for(s=0;s<f.length;++s)e.executeSql("SELECT * FROM items WHERE uuid=?",[f[s]],function(c,b){if(0<b.rows.length){var d=a(b.rows.item(0));y.items.push(d)}})},function(a){console.error("[DATASOURCE] Database error (syncData):"+(a?a.message:a));w&&w({error:a?
a.message:a})},function(){w&&w(y)})},U:function(a,c,b,d){var y=[],f=[],s=i,v=i;"*"!=b&&(s=ta(b),v=G(b));e.readTransaction(function(b){var d="SELECT uuid, overview, derived_hash, naked_hash, created_at, updated_at FROM items WHERE type_name=? AND trashed='N' AND scope <> 'Never'";c&&(d="SELECT uuid, overview, details, derived_hash, naked_hash, created_at, updated_at FROM items WHERE type_name=? AND trashed='N' AND scope <> 'Never'");var e=[a];s&&(d+=" AND (derived_hash=? OR naked_hash=?)",e.push(s),
e.push(v));b.executeSql(d,e,function(a,b){for(var d=0;d<b.rows.length;d++){var e=b.rows.item(d),v={uuid:e.uuid,overview:e.overview,derived_hash:e.derived_hash,naked_hash:e.naked_hash,created_at:e.created_at,updated_at:e.updated_at};c&&(v.details=e.details);y.push(v);v.derived_hash==s&&f.push(v)}})},function(a){a="Database error 5: "+(a?a.message:a);console.error("[DATASOURCE] "+a);d&&d({error:a})},function(){d&&d({nakedMatch:y,derivedMatch:f})})},w:function(c,b){var d=i;e.readTransaction(function(b){b.executeSql("SELECT * FROM items WHERE uuid=?",
[c],function(c,b){for(var e=0;e<b.rows.length;e++)d=a(b.rows.item(e))})},function(a){console.error("[DATASOURCE] Database error 2: "+(a?a.message:a));b&&b({error:a?a.message:a})},function(){b&&b({result:d})})},yb:function(c,d){var f={items:[]};e.readTransaction(function(d){b(d,f);for(var e=0;e<c.length;++e)d.executeSql("SELECT * FROM items WHERE uuid=?",[c[e]],function(c,b){var d=a(b.rows.item(0));f.items.push(d)})},function(a){console.error("[DATASOURCE] Database error (loadItemsForUUIDs): "+(a?
a.message:a));d&&d({error:a?a.message:a})},function(){d&&d(f)})},Na:function(a){var c={},d={hashes:c};e.readTransaction(function(a){b(a,d);a.executeSql("SELECT uuid, contents_hash FROM items",[],function(a,b){for(var d=0;d<b.rows.length;d++){var e=b.rows.item(d);c[e.uuid]=e.contents_hash}})},function(c){console.error("[DATASOURCE] Database error 6: "+(c?c.message:c));a&&a({error:c?c.message:c})},function(){a&&a(d)})},eb:function(a,c){e.transaction(function(c){for(var b in a)a.hasOwnProperty(b)&&c.executeSql("UPDATE items SET contents_hash=? WHERE uuid=?",
[a[b],b])},function(a){console.error("[DATASOURCE] Database error (saveItemHashes): "+(a?a.message:a));c&&c({error:a?a.message:a})},function(){c&&c()})},La:function(a,c){var b=G(a);if(b){var d=[];e.readTransaction(function(a){a.executeSql("SELECT uuid, autosave_token FROM items WHERE naked_hash=?",[b],function(a,c){for(var b=0;b<c.rows.length;b++){var e=c.rows.item(b);d.push({uuid:e.uuid,autosave_token:e.autosave_token})}})},function(a){console.error("[DATASOURCE] Database error (loadAutosaveTokensForURL): "+
(a?a.message:a));c&&c({error:a?a.message:a})},function(){c&&c({result:d})})}else c({result:[]})},z:function(){return p},u:function(){return f},jb:function(a){k||e.transaction(function(c){c.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["server_database_id",a])},function(a){console.error("Failed to set serverDatabaseID: "+a)},function(){k=a})},aa:function(){return k}}}(),M=function(){function a(){return!P||!E?l:g}function b(a){ea=i;I=g;A("unlock",{p:a})}function c(){a()?Q?
J.I("Failed to sync with helper"):J.I(i):J.I("Not connected to helper")}function d(){s+=1;s>=t.length&&(s=0,6E4>y&&(y+=2E3));var a="ws://127.0.0.1:"+t[s];E&&(E.close(),E=i);I=K=l;oa=-1;E=new WebSocket(a);E||(console.error("[AGENT] Failed to connect to "+t[s]),e(s==t.length-1?y:50));E.onerror=function(a){console.error("[AGENT] socket error: ",a);c()};E.onopen=function(){console.log("[AGENT] connected to port "+t[s]);A("hello",{k:sjcl.codec.hex.fromBits(v),enableUniversalUnlock:D.K()?"y":"n"});c()};
E.onmessage=function(a){try{var b=B.C(v,a.data),d=sjcl.codec.utf8String.fromBits(b),e=JSON.parse(d);e?k(e):console.error("[AGENT] Failed to parse incoming message")}catch(f){console.error("[AGENT] Exception in onmessage: "+f)}c()};E.onclose=function(a){console.log("[AGENT] close",a);P=i;c();e(s==t.length-1?y:50)};c()}function e(a){pa&&clearTimeout(pa);pa=setTimeout(d,a)}function f(){C.Na(function(a){j(g);var c={};c.hashes=a.hashes;c.key=a.key;C.aa()&&(c.serverDatabaseID=C.aa());H.B()&&(c.p=H.B());
A("syncRequest",c)})}function h(a){I=l;var c=H.a()?i:H.B(),d=a.p;H.a()&&D.K()&&d&&J.h(d);a.locked?c&&b(c):r(100)}function j(a){I=l;if(a!=K)(K=a)?(F.completedAt=i,F.startedAt=new Date):F.completedAt=new Date}function p(a,c,b,d){C.pb(a,c,b,function(a){if(0==b.length)d?(j(l),J.G()):r(100);else if(!a.error){a={key:a.key,requestedObjects:a.items};if(d)a.completed="Y",J.G();A("syncCompleteRequest",a)}})}function m(a,c){a?C.bb(a,c):c()}function k(a){var c=parseInt(a.number||"0",10);if(c<=oa)console.error("Invalid incoming message");
else if(oa=c,c=a.action,"heartbeat"===c)L.elapseTime=(new Date).getTime()-L.sentAt,L.count==a.payload.beats&&(L.acked=g);else if("welcome"===c)y=0,P=sjcl.codec.hex.toBits(a.payload.skey),c=a.payload.settings,D.ba(c),w=a.payload.diags,h(a.payload);else if("activate"===c)J.o(g);else if("allLogins"===c)J.da();else if("lock"===c)J.lock();else if("unlock"===c)h(a.payload);else if("unlockReply"===c)ea=a.payload.accepted,"N"==ea?I=l:(j(l),r(50));else if("setPreferences"===c)c=a.payload.settings,D.ba(c);
else if("triggerSync"===c)r(1200*Math.random());else if("syncReply"===c)if(I=l,a=a.payload,a.error)Q=a.error,console.error("[AGENT] syncReply error: "+Q),j(l);else{Q=i;j(g);var c=a.key,b=a.serverDatabaseID,d=a.updatedObjects||[],e=a.requestedUUIDs||[],f=a.uuidsToDelete||[],s="Y"==a.completed;b&&C.jb(b);m(c,function(){p(d,f,e,s)})}else if("syncCompleteReply"===c)a=a.payload,c=a.hashes,s="Y"==a.completed,C.eb(c,function(){s?j(l):r(100)})}function r(a){qa&&clearTimeout(qa);qa=setTimeout(f,a)}function A(a,
c){c||(c={});var b={action:a,number:++Ma,version:"2",bundleId:ya,payload:c},b=JSON.stringify(b),d=i;"hello"===a?(d=(new Date).getTime(),d=Math.floor(d/1E4),9==d%10&&(d+=1),d="Ds"+d+"y"+C.u()+"9",d=SHA256.sha256_digest(d),b=B.D(sjcl.codec.utf8String.toBits(d),sjcl.codec.utf8String.toBits(b))):b=!P?i:B.D(P,sjcl.codec.utf8String.toBits(b));(d=b)&&d&&E.send(d)}var t=[6258,10191,14821,24861,25007,38151,46360,49801,55730,59483],w={},y=0,ya=i,s=0,v=i,P=i,Ma=1,oa=-1,E=i,ea=i,I=l,K=l,Q=i,F={completedAt:i,
startedAt:i},L={timer:i,count:0,sentAt:i,acked:l,elapseTime:i},pa=0,qa=0;return{connect:function(a){ya=a;v=sjcl.random.randomWords(8,0);P=i;s=-1;e(100)},h:b,lock:function(){A("lock",{})},H:function(a){A("setPreferences",{autosave:a.autosave?"Y":"N",autosubmit:a.autosubmit?"Y":"N"})},ta:function(a){if("object"==typeof clipboard)return clipboard.set(a),g;if("object"==typeof chrome){var c=document.createElement("input");c.type="text";c.value=a;document.body.appendChild(c);c.select();document.execCommand("copy");
document.body.removeChild(c);return g}return M.c()?(A("copyToClipboard",{data:a}),g):l},Ua:function(){A("pressEnterKey",{})},Ka:function(){A("launch1Password",{})},rb:function(a){p([],[],[a],g)},ea:function(){var c="N/A";F.startedAt&&F.completedAt&&(c=F.completedAt.getTime()-F.startedAt.getTime());var b="N/A";F.completedAt&&(b=F.completedAt.getTime());return{connected:a(),lastSyncError:Q,diags:w,heartbeatAcked:L.acked,heartbeatElapseTime:L.elapseTime,heartbeatCount:L.count,heartbeatInterval:20,syncInProgress:K?
"Yes":"No",syncCompletedAt:b,syncElapseTime:c}},qb:function(){a()&&(K||I||f())},S:function(){return K},T:function(){return I},fa:function(){return ea},i:function(){return Q},$a:function(){if(!K)return 0;var a=F.startedAt;return!a?0:(new Date).getTime()-a.getTime()},c:a}}(),J=function(){function a(a){"object"==typeof safari?(safari.application.activeBrowserWindow||safari.application.openBrowserWindow(),safari.application.activeBrowserWindow.openTab("foreground").url=b(a)):"object"==typeof chrome?chrome.tabs.create({url:b(a)}):
"object"==typeof N?N.open(b(a)):console.error("[ONEPASSWORD] Browser not supported")}function b(a){return 0==a.indexOf("http://")||0==a.indexOf("https://")||0==a.indexOf("safari-extension://")||0==a.indexOf("chrome-extension://")||0==a.indexOf("resource://")?a:0<=a.indexOf(":443")?"https://"+a:"http://"+a}function c(a,c){va("webforms.WebForm",a,function(b){var d=b.derivedMatch,b=b.nakedMatch;m=i;d&&1===d.length?m=d[0].uuid:b&&1===b.length&&(m=b[0].uuid);m?(h(i,a,m),setTimeout(function(){m&&(m=i,f("logins"))},
900)):f("logins",c,i)})}function d(){if("object"==typeof safari)for(var a=0,c=safari.extension.popovers.length;a<c;a++){var b=safari.extension.popovers[a];b&&(b.hide(),safari.extension.removePopover(b.identifier))}}function e(a,c,b){O(i,"showPopup",{tab:a,locked:H.a(),fillLoginHotKeyUsed:c,fillLoginUuid:b})}function f(a,c,b){M.c()||M.connect();a==i&&(a="logins");if("object"==typeof safari){d();for(var f=safari.application.activeBrowserWindow,h=0,j=safari.extension.toolbarItems.length;h<j;h++){var k=
safari.extension.toolbarItems[h];if(k.browserWindow===f){a=safari.extension.createPopover("OnepasswordPopover",ha("data/ui/popup.html?tab="+a+"&locked="+(H.a()?"yes":"no")+"&fillLoginHotKeyUsed="+(c?"yes":"no"))+(b?"&fillLoginUuid="+b:""),300,312);k.popover=a;k.showPopover();return}}}else if("object"!=typeof chrome){wa(a,H.a(),c,b).show();return}e(a,c,b)}function h(a,c,b){C.w(b,function(b){if(b.result){b=b.result;xa(b);var e=D.d().autosubmit;O(a,"fillItem",{item:b,url:c,autosubmit:e});d()}})}var j=
0,p={},m=i,k=[],r={},A=(new Date).getTime(),t=i,w=i;goAndFillLoginWithUuid=function(c,e,f){if(!H.a()||!e)C.w(c,function(c){c=c.result;p[c.naked_hash]=c;if(e)if(xa(c),"NewTab"===f)a(c.location);else if("CurrentTab"===f)za(c.location);else if("NewWindow"===f)if(c=c.location,"object"==typeof safari){var d=safari.application.openBrowserWindow();(d.activeTab?d.activeTab:d.openTab("foreground")).url=b(c)}else"object"==typeof chrome?chrome.windows.create({url:b(c)}):"object"==typeof Aa?Aa.open({url:b(c)}):
console.error("[ONEPASSWORD] Browser not supported");else console.log("[ONEPASSWORD] Invalid tabMode: "+f)}),d()};checkForGoAndFill=function(a,c){var b=G(a);(b=p[b])?(!b.secureContents&&!H.a()&&xa(b),b.secureContents?c({item:b,url:a,autosubmit:D.d().autosubmit}):(c({locked:g}),f("logins",g,b.uuid))):c({})};removePendingLoginWithUUID=function(a){m==a&&(m=i);for(var c in p)if(p.hasOwnProperty(c)&&p[c].uuid==a){delete p[c];break}};removePendingAutosavesForTabId=function(a){try{var c=[],b;for(b in r)r.hasOwnProperty(b)&&
r[b].tabId===a&&c.push(b);for(b=0;b<c.length;++b)delete r[c[b]]}catch(d){o(d)}};addPendingAutosave=function(a,c,b){b.autosaveId=c;b.tabId=a;r[c]=b;setTimeout(function(){"object"==typeof safari&&!b.fullscreen?R.lb(b):"object"==typeof S&&S.mb(c)},500)};neverAutosaveWithId=function(a,c){D.Oa(r[a].location);M.H(D.getAll());removeAutosaveWithId(a,c)};disableAutosave=function(){D.l();M.H(D.getAll())};autosaveTokenForPasswordAndUUID=function(a,c){if(!a)return i;var b=sjcl.codec.utf8String.toBits(c+a),d=
sjcl.hash.sha256.hash(b),d=sjcl.bitArray.concat(d,b),d=sjcl.hash.sha256.hash(d),b=sjcl.bitArray.concat(d,b),b=sjcl.hash.sha256.hash(b),b=sjcl.codec.bytes.fromBits(b);return ba.ga(b).toString(16)};autosaveIfLoginDoesNotExist=function(a,c,b){var d=c.location,e=new ma(c.login),f=e.F();if(0===e.Qa().length)b&&b({});else{var h=++j;H.a()?C.La(d,function(d){if(d=d.result)for(var e=0;e<d.length;++e)if(autosaveTokenForPasswordAndUUID(f,d[e].uuid)==d[e].autosave_token)return;addPendingAutosave(a,h,c);b&&b({tabId:a,
autosaveId:h,locked:g})}):C.U("webforms.WebForm",g,d,function(d){for(var d=d.nakedMatch||[],f=0;f<d.length;f++){var j={secureContents:H.N(d[f].details)};if((new ma(j)).F()==e.F()){b({});return}}addPendingAutosave(a,h,c);b&&b({tabId:a,autosaveId:h})})}};scheduleAutosave=function(a,c,b){removePendingAutosavesForTabId(a);D.ca(c.location).autosave?autosaveIfLoginDoesNotExist(a,c,b):b&&b({})};pendingAutosaveForTab=function(a,c,b){var d=i,c=G(c),e;for(e in r)if(r.hasOwnProperty(e)){var f=r[e];if(a&&a==
f.tabId){d=f;break}if(!a&&c==G(f.location)){d=f;break}}b({tabId:a,autosave:d,locked:H.a()})};pendingAutosaveWithId=function(a,c){c({info:r[a],locked:H.a()})};removeAutosaveWithId=function(a,c){a&&delete r[a];c&&c({});"object"==typeof safari&&R.Ha()};beginManualSave=function(){k=[]};considerLoginForManualSave=function(a){a&&k.push(a)};getPendingLoginForManualSave=function(){for(var a=i,c=0,b=k.length;c<b;c++){var d=k[c];if(d&&(a==i||d.secureContents.fields.length>=a.secureContents.fields.length))a=
d}k=[];a&&!a.uuid&&(a.uuid=la.m());return a};diagnostics=function(){return{version:"3.8.8",instanceUUID:C.u().substring(0,8)+"..."+C.u().substring(60),uptime:(new Date).getTime()-A,databaseCreatedAt:C.ua()}};showWelcomeScreenOrRestartIfNeeded=function(a){a===i?J.n("http://help.agilebits.com/1Password3/3_minute_expert_new.html"):"3.8.8"!==a&&"com.apple.Safari"===T&&J.n("http://help.agilebits.com/1Password3/html/onepassword_extension_updated.html?currentVersion=3.8.8&previousVersion="+a)};allLoginsCache=
function(){return H.a()?[]:t?t:[]};reloadAllLoginsCache=function(){t=i;va("webforms.WebForm","*",function(a){if(!a.locked){a=a.nakedMatch;t=[];for(var c=0,b=a.length;c<b;c++){var d=a[c];d.overview.location=ka(d.overview.location);d.overview.title=ka(d.overview.title);delete d.title;delete d.location;t.push(d)}"object"==typeof chrome&&U.e()}})};loginsForURLUsingCache=function(a){var c=G(a),b=ta(a);return allLoginsCache().filter(function(a){return a.derived_hash===b||a.naked_hash===c})};none=function(){};
return{lock:function(){H.lock();p={};r={};t=i;Ba("lock",{});"object"==typeof chrome&&U.e()},h:function(a,c){C.Ma(function(b){b.error?c({state:"UnlockDatabaseFailure",error:"Problem with database",errorMessage:b.error}):(b=b.key)?(H.t(b.uuid,b.overview_key,b.details_key,b.validation,b.iterations),b=H.sb(a)?ca:u,c&&c({state:b}),b===ca&&(setTimeout(function(){reloadAllLoginsCache()},10),setTimeout(function(){M.qb()},200))):(b=x,c&&c({state:b,error:"Data not available",errorMessage:"Please wait..."}))})},
s:h,showPopover:f,nb:e,removePopover:d,oa:function(a,c){if("object"==typeof safari)for(var b=0,d=safari.extension.popovers.length;b<d;b++){var e=safari.extension.popovers[b];if(e)a.width&&(e.width=a.width),a.height&&(e.height=a.height),c&&c({})}},I:function(a){w=a;if("object"==typeof safari)for(var a=0,c=safari.extension.toolbarItems.length;a<c;++a)safari.extension.toolbarItems[a].badge=w?1:0;else"object"==typeof chrome?chrome.browserAction.setIcon({path:w?"data/images/toolbar-chrome-trouble.png":
"data/images/toolbar-chrome.png"}):"object"==typeof S&&S.kb(V.url(w?"images/toolbar-firefox-trouble.png":"images/toolbar-firefox.png"))},Db:function(){return w},o:function(a){if("object"==typeof safari){var b=safari.application.activeBrowserWindow;if(b)(b=b.activeTab)&&c(b.url,a)}else if("object"==typeof chrome)chrome.windows.getLastFocused(function(b){chrome.tabs.getSelected(b.id,function(b){b&&c(b.url,a)})});else if("object"==typeof N)(b=N.activeTab)&&c(b.url,a)},da:function(){f("logins")},n:a,
ka:allLoginsCache,G:reloadAllLoginsCache,A:loginsForURLUsingCache,g:goAndFillLoginWithUuid,qa:checkForGoAndFill,Za:removePendingLoginWithUUID,Ya:removePendingAutosavesForTabId,fb:scheduleAutosave,Ra:pendingAutosaveForTab,Sa:pendingAutosaveWithId,Z:removeAutosaveWithId,X:neverAutosaveWithId,l:disableAutosave,ma:beginManualSave,sa:considerLoginForManualSave,Ea:getPendingLoginForManualSave,ob:showWelcomeScreenOrRestartIfNeeded,O:diagnostics}}(),R=function(){function a(){for(var a=0;a<safari.extension.bars.length;++a){var d=
safari.extension.bars[a];b(d,i);d.hide(l)}}function b(a,b){if(a.contentWindow)a.contentWindow.removeAutosaveWithId=J.Z,a.contentWindow.neverAutosaveWithId=J.X,a.contentWindow.disableAutosave=J.l,a.contentWindow.unlockInGlobalPage=Ca,a.contentWindow.saveObject=Da,a.contentWindow.loadItemsOfType=va,a.contentWindow.loadObjectForUuid=Ea,a.contentWindow.setAutosaveInfo&&a.contentWindow.setAutosaveInfo(b,H.a())}return{Ia:function(){safari.application.addEventListener("beforeNavigate",R.ab,g);safari.application.addEventListener("command",
R.Ta,l);safari.application.addEventListener("contextmenu",R.Ga,l);safari.application.addEventListener("message",R.Fa,l);a()},Ha:a,lb:function(a){for(var d=l,e=0;e<safari.extension.bars.length;++e){var f=safari.extension.bars[e];if(f.browserWindow==safari.application.activeBrowserWindow){d=g;b(f,a);f.show(g);break}}if(!d){console.warn("[SAFARI] Failed to find the autosave bar to show, will display all");for(e=0;e<safari.extension.bars.length;++e)f=safari.extension.bars[e],b(f,a),f.show(g)}},Ga:function(a){if(H.a())a.contextMenu.appendContextMenuItem("onepassword-unlock",
"Unlock 1Password","showPopoverFromSafariContextMenu");else{a.contextMenu.appendContextMenuItem("onepassword-contextmenu","1Password","showPopoverFromSafariContextMenu");for(var b=J.A(safari.application.activeBrowserWindow.activeTab.url),e=0,f=b.length;e<f;++e){var h=b[e];a.contextMenu.appendContextMenuItem(h.uuid,"  "+z(h.overview.title),"safariFillLoginContextMenu")}}},Ta:function(a){"showPopover"===a.command&&J.showPopover("logins");"showPopoverFromSafariContextMenu"===a.command?J.nb("logins"):
"safariFillLoginContextMenu"===a.command&&J.s(safari.application.activeBrowserWindow.activeTab,safari.application.activeBrowserWindow.activeTab.url,a.target.identifier)},ab:function(a){if(a&&a.url)if(0===a.url.indexOf("http://agilebits.com/extension/activate"))a.preventDefault(),setTimeout(J.o,50);else if(0===a.url.indexOf("http://agilebits.com/extension/all_logins"))a.preventDefault(),setTimeout(J.da,50);else if(0===a.url.indexOf("http://agilebits.com/extension/lock"))a.preventDefault(),J.lock();
else{var b=a.url.indexOf("onepasswdfill=");if(0<b){var e=a.url.substr(b+14),b=a.url.substring(0,b-1);a.preventDefault();za(b);e&&J.g(e,l,"CurrentTab")}}},Fa:function(a){try{W(a.target,a.name,a.message,function(b){b={uuid:a.message.uuid,result:b};a&&a.target&&a.target.page&&a.target.page.dispatchMessage("performCallback",b)})}catch(b){o(b)}}}}(),U=function(){function a(a,b){chrome.contextMenus.create({title:z(a.overview.title),parentId:b,contexts:["all"],onclick:function(b,d){J.s(d,d.url,a.uuid)}})}
var b=i;return{ja:function(){chrome.extension.onRequest.addListener(function(a,b,e){try{a&&a.command?X(b.tab,a.command,a.params,function(a){e&&e(a)}):a&&a.name&&(W(b.tab,a.name,a.message),e&&e({}))}catch(f){o(f)}})},ia:function(){chrome.tabs.onUpdated.addListener(function(a,b,e){a=e.url;b=a.indexOf("onepasswdfill=");if(0<b){var f=a.substr(b+14);chrome.tabs.update(e.id,{url:a.substring(0,b-1)},i);f&&J.g(f,l,"CurrentTab")}})},ra:function(){chrome.omnibox.onInputStarted.addListener(function(){b=i});
chrome.omnibox.onInputChanged.addListener(function(a,d){var e=[];if(H.a())e.push({content:"Press Return to Unlock 1Password",description:"1Password is currently locked"});else if(0<a.length){var f=a.toLowerCase();b=i;for(var h=J.ka(),j=0;j<h.length;++j){var p=h[j],m=z(p.overview.title),k=z(p.overview.location);m||(m="");k||(k="");var r=m.toLowerCase(),k=k.toLowerCase();if(0<=r.indexOf(f)||0<=k.indexOf(f))e.push({content:"Open "+m+"\n"+p.uuid,description:"<match>"+m.replace(/</gm,"&lt;").replace(/>/gm,
"&gt;","gm").replace(/&/gm,"&amp;")+"</match> &lt;<url>"+ia(k)+"</url>&gt;"}),1==e.length&&(b=p.uuid)}}d(e)});chrome.omnibox.onInputEntered.addListener(function(a){if(H.a()||""===a.trim())J.o();else{var a=a.split("\n"),d=i;(d=2===a.length?a[1]:b)?J.g(d,g,"CurrentTab"):J.o()}});chrome.omnibox.setDefaultSuggestion({description:"<url><match>1Password:</match></url><dim> type </dim>Login<dim> name or press </dim>Return<dim> to show 1Password popup.</dim>"})},e:function(){chrome.contextMenus.removeAll();
H.a()?chrome.contextMenus.create({title:"Unlock 1Password",contexts:["all"],onclick:function(){J.showPopover()}}):(chrome.contextMenus.create({title:"Open 1Password",contexts:["all"],onclick:function(){J.showPopover()}}),chrome.windows.getLastFocused(function(b){chrome.tabs.getSelected(b.id,function(b){if(b&&(b=J.A(b.url),0!==b.length))for(var c=chrome.contextMenus.create({title:"Fill Login",contexts:["all"]}),f=0,h=b.length;f<h;++f)a(b[f],c)})}))}}}(),Fa={},Ga=0;
function Ha(a){"object"==typeof safari?a(safari.application.activeBrowserWindow.activeTab.url):"object"==typeof chrome?chrome.windows.getLastFocused(function(b){chrome.tabs.getSelected(b.id,function(b){a(b.url)})}):"object"==typeof N&&a(N.activeTab.url)}
function O(a,b,c){try{if(c||(c={}),"object"==typeof safari){if(!a)a=safari.application.activeBrowserWindow.activeTab;a&&(a.page?a.page.dispatchMessage(b,c):console.error("Error: tab.page not available"))}else if("object"==typeof chrome)a&&0<=a.id?chrome.tabs.sendRequest(a.id,{name:b,message:c},function(){}):chrome.windows.getLastFocused(function(a){chrome.tabs.getSelected(a.id,function(a){chrome.tabs.sendRequest(a.id,{name:b,message:c},function(){})})});else if("object"==typeof N){if(!a)a=N.activeTab;
for(var d=Ia(a),a=0;a<d.length;++a)d[a].port.emit("message",{name:b,message:c})}}catch(e){o(e)}}
function Ba(a,b){try{if("object"==typeof safari)for(var c=safari.application.browserWindows,d=0;d<c.length;++d)for(var e=c[d].tabs,f=0;f<e.length;++f)O(e[f],a,b);else if("object"==typeof chrome)chrome.windows.getAll({populate:g},function(c){for(var d=0,e=c.length;d<e;d++)for(var f=c[d],h=0,A=f.tabs.length;h<A;h++)chrome.tabs.sendRequest(f.tabs[h].id,{name:a,message:b},function(){chrome.extension.Ja&&console.log("[GLOBAL] sendRequest Error: %s",chrome.extension.Ja.message)})});else if("object"==typeof e){d=
0;for(f=e.length;d<f;++d)O(e[d],a,b)}}catch(h){o(h)}}function Ja(a){if("object"==typeof chrome)return a.id;var b=a.com_agilebits_id;if(!b)b=++Ga,a.com_agilebits_id=b;return b}function Ka(a){return"object"==typeof chrome?a?a.id:i:!a?i:a.com_agilebits_id}function xa(a){try{if(!H.a()){var b=H.r(a.overview);a.overview=b;a.title=b.title;a.location=b.location;a.secureContents=H.N(a.details);delete a.details}}catch(c){o(c)}}
function Da(a,b){try{if(H.a())b({locked:g,error:"Failed to save because 1Password is locked."});else{var c={};c.uuid=a.uuid?a.uuid:la.m();c.type_name=a.type_name;c.overview=a.overview?H.P(JSON.stringify(a.overview)):H.P(JSON.stringify({title:a.title,location:a.location}));a.folder_uuid&&(c.folder_uuid=a.folder_uuid);c.derived_hash=ta(a.overview.location);c.naked_hash=G(a.overview.location);c.details=H.xa(JSON.stringify(a.secureContents));c.trashed=a.trashed||"N";c.scope="Regular";var d=Math.round((new Date).getTime()/
1E3);c.created_at=a.created_at?a.created_at:d;c.updated_at=d;c.contents_hash="777";C.cb(c,function(){J.G();b({})});setTimeout(function(){M.rb(c.uuid)},100)}}catch(e){o(e)}}function La(a,b){var c=a.title,d=b.title;return!c?-1:!d?1:c.toLowerCase().localeCompare(d.toLowerCase())}function Na(a,b){var c=a.created_at,d=b.created_at;return!d?-1:!c?1:d-c}
function Oa(a){if(!a)return"n/a";var b=(Math.round((new Date).getTime()/1E3)-a)/60;if(1>=b)return"just now";a=b/60;if(1>=a)return Math.round(b)+" min ago";b=a/24;if(1>=b)return Math.round(a)+" hours ago";a=b/7;if(2>=a)return Math.round(b)+" days ago";b=a/4.33;if(2>=b)return Math.round(a)+" weeks ago";a/=52;return 2>=a?Math.round(b)+" months ago":Math.round(a)+" years ago"}function Pa(a){return Oa(a.created_at)+" - "+a.title}
function va(a,b,c){if(H.a())c({locked:g,error:"Failed to load items because 1Password is locked."});else{if(b==i&&"object"==typeof safari)b=safari.application.activeBrowserWindow.activeTab.url;if(b==i||void 0==b)b="";"webforms.WebForm"!==a&&"passwords.Password"!==a&&(b="*");var d,e;"passwords.Password"===a?(d=Na,e=Pa):(d=La,e=i);C.U(a,l,b,function(a){var b;b=a.nakedMatch;for(var j=e,p=d,m=0;m<b.length;m++){var k=b[m],r=H.r(k.overview);if(r)k.overview=r,k.title=k.overview.title,k.location=k.overview.location;
if(k.details)(r=H.r(k.details))&&(k.secureContents=r);j&&(k.display_title=j(k))}b=b.sort(p);a=a.derivedMatch.sort(d);c({nakedMatch:b,derivedMatch:a,locked:l})})}}function Ea(a,b){H.a()?b({locked:g,error:"Failed to load object because 1Password is locked."}):C.w(a,function(a){a=a.result;xa(a);b({object:a})})}
function Ca(a,b,c){(M.S()||M.T())&&!b&&16E3>M.$a()?c({state:fa}):J.h(a,function(d){var e=d.state;b&&e===u&&M.c()?(setTimeout(function(){M.h(a)},50),c({state:x})):!b&&e===u&&M.c()&&"Y"==M.fa()&&M.i()?"serverDatabaseIDMismatch"==M.i()?c({state:ga,error:"1Password Database Mismatch",errorMessage:"Re-install the extension to fix this problem.",clearPassword:g}):"problemWithKeys.tryOldPassword"==M.i()?c({state:ga,error:"Master Password Changed",errorMessage:"Enter previous password to update the extension.",
clearPassword:g}):c({state:ga,error:M.i(),errorMessage:"Please ensure you have the latest version of the main 1Password app.",clearPassword:g}):e!==x?(c(d),e===ca&&setTimeout(function(){M.h(a)},50)):M.c()?M.S()||M.T()?c({state:fa}):b?(setTimeout(function(){M.h(a)},50),c({state:x})):"N"==M.fa()?c({state:u}):(console.error("[GLOBAL] Unknown performUnlock error"),c({state:ga,error:"Unknown error",errorMessage:"Please ensure you have the latest version of the main 1Password app."})):c({state:da})})}
function X(a,b,c,d){if("loadItemsOfType"===b)va(c.type,c.url,d);else if("getPopupOptions"===b){var e=c.options;e.locked=H.a();e.agentIsConnected=M.c();e.settings=D.d();e.troubleshooting=M.c()&&!M.i()?"no":"yes";Ha(function(a){e.url=a;d({options:e})})}else if("saveSettings"===b)D.ib(c.settings),d({}),setTimeout(function(){M.H(c.settings)},100);else if("loadAllSettings"===b)d({settings:D.d(),locked:H.a(),agentIsConnected:M.c()});else if("loadSettingsForURL"===b)b=D.ca(c.url),d(b);else if("changePopupSize"===
b)J.oa(c,d);else if("performUnlock"===b)Ca(c.p,c.userInitiated,d);else if("saveObject"===b)Da(c,d);else if("loadObjectForUuid"===b)Ea(c.uuid,d);else if("scheduleAutosave"===b)a=Ja(a),J.fb(a,c,d);else if("pendingAutosaveForTab"===b)J.Ra(Ka(a),c.url,d);else if("pendingAutosaveWithId"===b)J.Sa(c.autosaveId,d);else if("removeAutosaveWithId"===b)b=c.autosaveId,J.Z(b,d),Ba("removeAutosave",{autosaveId:b});else if("neverAutosaveWithId"===b)b=c.autosaveId,Ba("removeAutosave",{autosaveId:b}),J.X(b,d);else if("loadPasswordOptions"===
b)d(D.Da());else if("savePasswordOptions"===b)D.hb(c),d({});else if("performLock"===b)J.lock(),d&&d({}),D.K()&&setTimeout(function(){M.lock()},300);else if("loadDocument"===b){var b=c.documentUUID,f=c.documentURL,a=Ja(a),h=Fa[a];h||(h={});h[b]={documentURL:f,login:i};Fa[a]=h;d({tabId:a})}else if("unloadDocument"===b){b=c.documentUUID;if(a=Ka(a))(h=Fa[a])&&delete h[b];d({})}else if("considerLoginForManualSave"===b)J.sa(c.login);else if("getPendingLoginForManualSave"===b)d({result:J.Ea()});else if("isLocked"===
b)d(H.a());else if("checkForGoAndFill"===b)J.qa(c.url,d);else if("getTroubleshootingInfo"===b)b={},b.agent=M.ea(),b.extension=J.O(),b.settings=D.d(),d(b);else if("copyToClipboard"===b)d({copied:M.ta(c.data)});else return console.log("[GLOBAL] Unknown command: "+b),"Unknown"}
function W(a,b,c,d){if("perform"===b)X(a,c.command,c.params,function(a){d(a)});else if("cancelAll"===b)(b=Ka(a))&&J.Ya(b),O(a,"cancelAll"),J.removePopover();else if("launch1Password"===b)M.c()?M.Ka():"object"==typeof safari&&navigator.userAgent.match(/OS X/)&&Qa();else if("showTroubleshootingReport"===b){a="data/ui/troubleshooting.html";"object"==typeof Ra&&(a="ui/troubleshooting.html");c=ha(a);if("object"==typeof Ra)var a=escape(escape(JSON.stringify(M.ea()))),b=escape(escape(JSON.stringify(J.O()))),
e=escape(escape(JSON.stringify(D.d()))),c=c+("?agent="+a+"&extension="+b+"&settings="+e);J.n(c);J.removePopover()}else if("goAndFillLoginWithUuid"==b)J.g(c.uuid,g,D.d().tabUsedForGoAndFill);else if("fillItemWithUuid"==b)b=c.uuid,c=c.url,J.s(a,c,b);else if("removePendingLoginWithUUID"===b)J.Za(c.uuid);else if("beginManualSave"==b)J.ma(),O(a,"collectForms");else if("disableAutosave"===b)J.l();else if("pressEnterKey"==b)M.Ua();else if("showUserGuide"==b)J.n("http://help.agilebits.com/1Password3/3_minute_expert_new.html"),
J.removePopover();else if("unloadDocument"===b&&(c=c.documentUUID,b=Ka(a)))(a=Fa[b])&&delete a[c]}function Qa(){if("object"==typeof safari){var a=safari.application.activeBrowserWindow.openTab("background");a.url="x-onepassword://";setTimeout(function(){a.close()},5)}}
function za(a){if("object"==typeof safari)safari.application.activeBrowserWindow.activeTab.url=a;else if("object"==typeof chrome)chrome.tabs.getSelected(i,function(b){chrome.tabs.update(b.id,{url:a},i)});else if("object"==typeof N)N.activeTab.url=a}var T=i;
if("object"==typeof safari)T="com.apple.Safari",R.Ia();else if("object"==typeof chrome)T="com.google.Chrome",U.ra(),U.ja(),U.ia(),U.e(),chrome.tabs.onSelectionChanged.addListener(function(){U.e()}),chrome.tabs.onUpdated.addListener(function(){U.e()});else{var T="org.mozilla.firefox",Sa=require("api-utils/preferences-service");"aurora"==Sa.get("app.update.channel")&&(T="org.mozilla.aurora");"nightly"==Sa.get("app.update.channel")&&(T="org.mozilla.nightly")}
if("object"==typeof window)window.performCommand=X,window.handleMessageEvent=W;setTimeout(function(){C.t(function(){J.ob(C.Va());M.connect(T)})},100);var Ra=require("page-mod"),Ta=require("widget"),N=require("tabs"),V=require("self").data;require("hotkeys");var na=require("simple-storage").storage,clipboard=require("clipboard"),Ua=require("context-menu"),Aa=require("windows").browserWindows,Va=i,Y=[];function Ia(a){for(var b=[],c=0;c<Y.length;++c)Y[c].tab==a&&b.push(Y[c]);return b}
function wa(a,b,c,d){a||(a="logins");b||(b=g);b="tab="+a+"&locked="+(b?"yes":"no")+"&fillLoginHotKeyUsed="+(c?"yes":"no");d&&(b=b+"&fillLoginUuid="+d);var e=require("panel").Panel({contentURL:V.url("ui/popup.html?"+b),contentScriptWhen:"ready",contentScriptFile:[V.url("../src/ext/json2-min.js"),V.url("../src/ext/sjcl.js"),V.url("../src/ext/jquery-1.7.1.min.js"),V.url("../src/popup.min.js"),V.url("../src/ext/jquery.tools.min.js")],onShow:function(){this.port.emit("show",{url:N.activeTab.url,tab:a,
locked:H.a(),settings:D.d(),troubleshooting:M.c()?"no":"yes"})},onHide:function(){this.port.emit("hide",{})}});e.width=300;e.height=312;e.port.on("error",function(a){console.error("[FIREFOX] Error: "+a)});e.port.on("perform",function(a){try{X(e,a.command,a.params,function(b){e.port.emit("callback",{uuid:a.uuid,result:b})})}catch(b){o(b)}});e.port.on("message",function(a){W(N.activeTab,a.name,a.message,i);"beginManualSave"!==a.name&&"copyToClipboard"!==a.name&&e.hide()});return e}
var Z={M:function(a){var b=a.indexOf("onepasswdfill=");if(0>=b)return i;var c=a.substr(b+14),a=a.substring(0,b-1);return 1>c.length?i:{uuid:c,url:a}},pa:function(){if(N&&N.activeTab&&N.activeTab.url){var a=Z.M(N.activeTab.url);a&&(za(a.url),J.g(a.uuid,l,"CurrentTab"))}},observe:function(a){var b=a.QueryInterface(Ci.nsIHttpChannel),c=Z.M(b.URI.spec);if(c)a.cancel(0),(a=Z.Ba(b))?a.location=c.url:za(c.url),J.g(c.uuid,l,"CurrentTab")},Ba:function(a){try{var b=a.notificationCallbacks?a.notificationCallbacks:
a.loadGroup.notificationCallbacks;return!b?i:b.getInterface(Ci.nsIDOMWindow)}catch(c){return i}},Y:function(){return Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService)},Xa:function(){Z.Y().addObserver(Z,"http-on-modify-request",l)},Eb:function(){Z.Y().Bb(Z,"http-on-modify-request")}};
exports.main=function(a){Z.Xa();setTimeout(function(){Z.pa()},500);var b=require("toolbarbutton").ToolbarButton({id:"onepassword-toolbar-button",label:"1Password",image:V.url("images/toolbar-firefox.png"),onCommand:function(a){wa("logins",H.a(),l,i).show(a)}});console.log("loadReason=<"+a.loadReason+">");b.moveTo({toolbarID:"nav-bar",forceMove:l});Ra.PageMod({include:["*"],contentScriptWhen:"ready",contentScriptFile:[V.url("src/end.min.js"),V.url("src/ext/json2-min.js")],onAttach:function(a){Y.push(a);
a.on("detach",function(){var a=Y,b=a.indexOf(this);-1!=b&&a.splice(b,1)});a.port.on("message",function(b){W(a.tab,b.name,b.message,i)});a.port.on("perform",function(b){try{X(a,b.command,b.params,function(e){a.port.emit("callback",{uuid:b.uuid,result:e})})}catch(e){o(e)}})}});Ta.Widget({id:"show-onepassword-popup",label:"Show 1Password",contentURL:V.url("ui/widget.html"),panel:wa("logins",H.a(),l,i),width:24});N.on("activate",function(){S.e()});N.on("ready",function(){S.e()})};
exports.onUnload=function(a){"uninstall"===a&&(a=Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("ProfD",Ci.nsIFile),a.append(".."),a.append("OnePassword.sqlite"),a.remove(l))};
var S=function(){function a(a,c){var d=require("panel").Panel({contentURL:V.url("ui/autosave3.html?locked="+(a?"yes":"no")+"&autosaveId="+c),contentScriptWhen:"start",contentScriptFile:[V.url("../src/ext/json2-min.js"),V.url("../src/ext/sjcl.js"),V.url("../src/ext/jquery-1.7.1.min.js"),V.url("../src/autosave3.min.js")],onShow:function(){this.port.emit("show",{locked:H.a()})},onHide:function(){this.port.emit("hide",{})}});d.width=270;d.height=120;d.port.on("error",function(a){console.log("[FIREFOX] Autosave Error: "+
a)});d.port.on("perform",function(a){try{"hidePopup"==a.command?d.hide():X(d,a.command,a.params,function(b){d.port.emit("callback",{uuid:a.uuid,result:b})})}catch(b){o(b)}});d.port.on("message",function(a){W(N.activeTab,a.name,a.message,i)});return d}return{mb:function(b){var c=i;try{var d=Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);if(d){var e=d.getMostRecentWindow("navigator:browser");e&&e.document&&(c=e.document.getElementById("onepassword-toolbar-button"))}}catch(f){o(f)}a(H.a(),
b).show(c)},kb:function(a){try{var c=Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);if(c)for(var d=c.getEnumerator("navigator:browser");d.hasMoreElements();){var e=d.getNext();e&&e.document&&(tbb=e.document.getElementById("onepassword-toolbar-button"))&&tbb.getAttribute("image")!=a&&tbb.setAttribute("image",a)}}catch(f){o(f)}},e:function(){Va&&Va.destroy();Va=Ua.Item({label:"1Password",contentScript:"self.on(\"click\", function (node, data) {   self.postMessage({'name':'click', 'data':node});  });  self.on(\"context\", function (node) {\t   self.postMessage({'name':'showing'});     return true;  });",
onMessage:function(a){a=a.name;if("click"===a)wa(i,H.a(),l,i).show();else if("showing"===a)this.label=H.a()?"Unlock 1Password":"1Password"}})},vb:function(a){if(!a||""===a)return[];for(var c=[],a=J.A(a),d=0,e=a.length;d<e;++d){var f=a[d];c.push(Ua.Item({label:z(f.overview.title),data:f.uuid}))}return c}}}();
